@@ -723,39 +723,6 @@ gboolean FileIs_png (gchar *namefile)
 
 	return (bool_signature);
 }
-// FILE IS JPG / JPEG ?
-//
-gboolean FileIs_jpg (gchar *namefile)
-{
-	FILE        *fp = NULL;
-	gchar       *buf = NULL;
-	gint         cpt;
-	gboolean     bool_signature = FALSE;
-	
-	/*PRINT_FUNC_LF();*/
-
-	buf = (gchar *)g_malloc0 (sizeof(gchar) * 5124);
-	if ((fp = fopen (namefile, "rb")) != NULL) {
-		fread (buf, 1, 5120, fp);
-		fclose (fp);
-	}
-	
-	for (cpt = 0; cpt < 5120; cpt ++) {
-		if(
-			buf [ cpt + 0 ] == 0x4A &&	// 'J'
-			buf [ cpt + 1 ] == 0x46 &&	// 'F'
-			buf [ cpt + 2 ] == 0x49	&&	// 'I'
-			buf [ cpt + 3 ] == 0x46		// 'F'
-		    ) {	
-		    bool_signature = TRUE;
-		    break;
-		}
-	}
-	g_free (buf);
-	buf = NULL;
-
-	return (bool_signature);
-}
 // 
 // 
 gboolean FileIs_image( gchar *PathNameFile )
@@ -769,6 +736,50 @@ gboolean FileIs_image( gchar *PathNameFile )
 	}
 	return( FALSE );
 }
+// 
+// FILE IS JPG / JPEG ?
+// L'EXTENTION 'JPG' OU 'JPEG' OBLIGATOIRE
+// ([ BYTE 00 ] & 0xd8ff ) == 0xd8ff
+// 
+gboolean FileIs_jpg( gchar *p_PathName )
+{
+	gchar		*PtrExtPathName = NULL;
+	gchar		*StrExtPathName = NULL;
+	FILE		*fp = NULL;
+	guint		buf[ 4 ] = { 0,0,0,0 };
+	gboolean	BoolRet = FALSE;
+	
+	// TEST PARAMETRE
+	if( NULL != p_PathName && NULL != ( PtrExtPathName = strrchr( p_PathName, '.' ))) {
+			
+		PtrExtPathName ++;
+		
+		if( strlen( PtrExtPathName ) >= 3 ) {
+			
+			StrExtPathName = g_strdup( PtrExtPathName );
+			PtrExtPathName = StrExtPathName;
+
+			// EXTENTIONS TO UPPER 
+			while( *PtrExtPathName ) {
+				*PtrExtPathName = g_unichar_toupper( *PtrExtPathName );
+				PtrExtPathName ++;
+			}
+			
+			if( 0 == g_ascii_strncasecmp( StrExtPathName, "JPG", 3 ) || 0 == g_ascii_strncasecmp( StrExtPathName, "JPEG", 4 ) ) {
+	
+				if( NULL != ( fp = g_fopen( p_PathName, "rb" ))) {
+					fread (buf, 1, 2, fp);
+					fclose( fp );
+					if( (buf [ 0 ] & 0xd8ff ) == 0xd8ff ) BoolRet = TRUE;
+				}
+			}
+			
+			g_free( StrExtPathName );	StrExtPathName = NULL;
+		}
+	}
+	
+	return( BoolRet );
+}
 
 
 
