@@ -57,11 +57,19 @@
 OPTIONS_COMMAND_LINE OptionsCommandLine = {
 	FALSE,		// gboolean	BoolVerboseMode
 	FALSE,		// gboolean	BoolVersionMode
-	FALSE,		// gboolean	BoolHelpMode
-	FALSE		// gboolean	BoolSystray
+	FALSE		// gboolean	BoolHelpMode
 };
 
 
+/*
+typedef struct {
+	guint32 pixel;
+	guint16 red;
+	guint16 green;
+	guint16 blue;
+} GdkColor;
+*/
+GdkColor YellowColor = { 0, 63479,63479,48830 };
 
 // 
 // 
