@@ -75,7 +75,6 @@
 #include "cd_cue.h"
 #include "notify_send.h"
 #include "win_scan.h"
-#include "popup_systray.h"
 #include "win_vte.h"
 #include "cd_audio_extract.h"
 
@@ -1426,7 +1425,6 @@ static gint cdaudioextract_timeout (gpointer data)
 		GList		*List = NULL;
 		FILE		*fp = NULL;
 
-		PopupSystray_set_BoolMainAction (FALSE);
 		gtk_timeout_remove (conv.handler_timeout_conv);
 
 		// Creation du fichier *.m3u
@@ -1986,8 +1984,6 @@ void cdaudioextract_extraction_cd_to_file_action (void)
 	VarCdExtract.PtrDirActuel = g_get_current_dir ();
 	g_chdir (conv.TmpRep);
 	
-	PopupSystray_set_BoolMainAction (TRUE);
-	
 	conv.bool_thread_conv = TRUE;
  	pthread_create (&nmr_tid, NULL ,(void *)cdaudioextract_thread_conversion_from_cd, (void *)NULL);
 	conv.bool_thread_extract = TRUE;
