@@ -30,11 +30,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <string.h>
@@ -157,18 +152,21 @@ void cdaudiotoc_reffresh_list_cd (void)
 		PRINT_FUNC_LF();
 		if( FALSE == libutils_find_file( "icedax" ) && FALSE == libutils_find_file( "cdda2wav" )) {
 			wininfo_create (
+				WindMain,
 				_("cdda2wav and icedax NOT FOUND"),
 				_("Please, install packages [ icedax, cdda2wav ]"),
 			  	"");
 		}
 		else if( FALSE == libutils_find_file( "icedax" )) {
 			wininfo_create (
+				WindMain,
 				_("icedax NOT FOUND"),
 				_("Please, install package [ icedax ]"),
 			  	"");
 		}
 		else if( FALSE == libutils_find_file( "cdda2wav" )) {
 			wininfo_create (
+				WindMain,
 				_("cdda2wav NOT FOUND"),
 				_("Please, install package [ cdda2wav ]"),
 			  	"");
@@ -178,6 +176,7 @@ void cdaudiotoc_reffresh_list_cd (void)
 	if( FALSE == PrgInit.bool_cdparanoia ) {
 		PRINT_FUNC_LF();
 		wininfo_create (
+			WindMain,
 			_("cdparanoia NOT FOUND"),
 			_("Please, install package [ cdparanoia ]"),
 		  	"");
@@ -185,6 +184,7 @@ void cdaudiotoc_reffresh_list_cd (void)
 	}
 	if( FALSE == PrgInit.bool_cd_discid ) {
 		wininfo_create (
+			WindMain,
 			_("cd-discid NOT FOUND"),
 			_("Please, install packages [ cd-discid ]"),
 		  	"");
@@ -199,6 +199,7 @@ void cdaudiotoc_reffresh_list_cd (void)
 		if( '\0' == *Config.entry_proxy_port ) BoolAccess = FALSE;
 		if( FALSE == BoolAccess ) {
 			wininfo_create (
+				WindMain,
 				_("ERREUR datas proxy"),
 				_("Veuillez renseigner les champs du proxy"),
 			  	"");
@@ -233,6 +234,7 @@ void cdaudiotoc_button_eject_cd_clicked (void)
 	if (FALSE == libutils_find_file ("eject")) {
 		PRINT_FUNC_LF();
 		wininfo_create (
+			WindMain,
 			"eject NOT FOUND !",
 			"Please, install package [ eject ]",
 		  	"");
