@@ -29,11 +29,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <glib.h>
 #include <glib/gstdio.h>
@@ -278,7 +273,8 @@ void dvdread_create_list_with_data (void)
 			/* PRECAUTION
 			*/
 			if (dvd_data.titles[ title_actif ].length == NULL) {
-				g_print ("******* SORTIE UN\n");
+				if( TRUE == OptionsCommandLine.BoolVerboseMode )
+					g_print ("******* SORTIE UN\n");
 				continue;
 			}
 
@@ -348,7 +344,8 @@ void dvdread_create_list_with_data (void)
 		/* PRECAUTION
 		*/
 		if (NULL == (dvd_data.titles[ title_actif ].length)) {
-			g_print ("******* SORTIE DEUX\n");
+			if( TRUE == OptionsCommandLine.BoolVerboseMode )
+				g_print ("******* SORTIE DEUX\n");
 			continue;
 		}
 
@@ -366,7 +363,8 @@ void dvdread_create_list_with_data (void)
 					/* PRECAUTION
 					*/
 					if (dvd_data.titles[ title_actif ].audio[ audio_actif ].Frequency == 0) {
-						g_print ("******* SORTIE TROIS\n");
+						if( TRUE == OptionsCommandLine.BoolVerboseMode )
+							g_print ("******* SORTIE TROIS\n");
 						continue;
 					}
 
@@ -428,59 +426,59 @@ void dvdread_print_data_struct (void)
 	gint          audio_actif = -1;
 
 	/*PRINT_FUNC_LF();*/
+	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+		g_print ("DiscTitle:       %s\n", dvd_data.DiscTitle);
+		g_print ("LongestTrack:    %d\n", dvd_data.LongestTrack);
 
-	g_print ("DiscTitle:       %s\n", dvd_data.DiscTitle);
-	g_print ("LongestTrack:    %d\n", dvd_data.LongestTrack);
+		g_print ("max_cells:       %d\n", dvd_data.max_cells);
+		g_print ("max_subpictures: %d\n", dvd_data.max_subpictures);
+		g_print ("max_titles:      %d\n", dvd_data.max_titles);
+		for (title_actif = 0; title_actif < dvd_data.max_titles; title_actif ++) {
+			g_print ("Title: %02d\n", title_actif +1);
 
-	g_print ("max_cells:       %d\n", dvd_data.max_cells);
-	g_print ("max_subpictures: %d\n", dvd_data.max_subpictures);
-	g_print ("max_titles:      %d\n", dvd_data.max_titles);
-	for (title_actif = 0; title_actif < dvd_data.max_titles; title_actif ++) {
-		g_print ("Title: %02d\n", title_actif +1);
+			g_print ("dvd_data.titles[ %02d ].length: %s\n", title_actif +1, dvd_data.titles[ title_actif ].length);
 
-		g_print ("dvd_data.titles[ %02d ].length: %s\n", title_actif +1, dvd_data.titles[ title_actif ].length);
+			g_print ("dvd_data.titles[ %02d ].max_chapter: %d\n", title_actif +1, dvd_data.titles[ title_actif ].max_chapter);
+			for (chapter_actif = 0; chapter_actif < dvd_data.titles[ title_actif ].max_chapter; chapter_actif ++) {
+				g_print ("dvd_data.titles[ %02d ].chapters[ %02d ].Length: %s\n",
+						title_actif +1,
+						chapter_actif +1,
+						dvd_data.titles[ title_actif ].chapters[ chapter_actif ].Length);
+			}
 
-		g_print ("dvd_data.titles[ %02d ].max_chapter: %d\n", title_actif +1, dvd_data.titles[ title_actif ].max_chapter);
-		for (chapter_actif = 0; chapter_actif < dvd_data.titles[ title_actif ].max_chapter; chapter_actif ++) {
-			g_print ("dvd_data.titles[ %02d ].chapters[ %02d ].Length: %s\n",
+			g_print ("dvd_data.titles[ %02d ].max_audio: %d\n", title_actif +1, dvd_data.titles[ title_actif ].max_audio);
+			for (audio_actif = 0; audio_actif < dvd_data.titles[ title_actif ].max_audio; audio_actif ++) {
+				g_print ("dvd_data.titles[ %02d ].audio[ %02d ].Language: %s\n",
 					title_actif +1,
-					chapter_actif +1,
-					dvd_data.titles[ title_actif ].chapters[ chapter_actif ].Length);
-		}
-
-		g_print ("dvd_data.titles[ %02d ].max_audio: %d\n", title_actif +1, dvd_data.titles[ title_actif ].max_audio);
-		for (audio_actif = 0; audio_actif < dvd_data.titles[ title_actif ].max_audio; audio_actif ++) {
-			g_print ("dvd_data.titles[ %02d ].audio[ %02d ].Language: %s\n",
-				title_actif +1,
-				audio_actif +1,
-				dvd_data.titles[ title_actif ].audio[ audio_actif ].Language);
-			g_print ("dvd_data.titles[ %02d ].audio[ %02d ].Lang: %s\n",
-				title_actif +1,
-				audio_actif +1,
-				dvd_data.titles[ title_actif ].audio[ audio_actif ].Lang);
-			g_print ("dvd_data.titles[ %02d ].audio[ %02d ].Format: %s\n",
-				title_actif +1,
-				audio_actif +1,
-				dvd_data.titles[ title_actif ].audio[ audio_actif ].Format);
-			g_print ("dvd_data.titles[ %02d ].audio[ %02d ].Frequency: %d\n",
-				title_actif +1,
-				audio_actif +1,
-				dvd_data.titles[ title_actif ].audio[ audio_actif ].Frequency);
-			g_print ("dvd_data.titles[ %02d ].audio[ %02d ].Quantization: %s\n",
-				title_actif +1,
-				audio_actif +1,
-				dvd_data.titles[ title_actif ].audio[ audio_actif ].Quantization);
-			g_print ("dvd_data.titles[ %02d ].audio[ %02d ].Channels: %d\n",
-				title_actif +1,
-				audio_actif +1,
-				dvd_data.titles[ title_actif ].audio[ audio_actif ].Channels);
-			g_print ("dvd_data.titles[ %02d ].audio[ %02d ].StreamId: %s\n",
-				title_actif +1,
-				audio_actif +1,
-				dvd_data.titles[ title_actif ].audio[ audio_actif ].StreamId);
+					audio_actif +1,
+					dvd_data.titles[ title_actif ].audio[ audio_actif ].Language);
+				g_print ("dvd_data.titles[ %02d ].audio[ %02d ].Lang: %s\n",
+					title_actif +1,
+					audio_actif +1,
+					dvd_data.titles[ title_actif ].audio[ audio_actif ].Lang);
+				g_print ("dvd_data.titles[ %02d ].audio[ %02d ].Format: %s\n",
+					title_actif +1,
+					audio_actif +1,
+					dvd_data.titles[ title_actif ].audio[ audio_actif ].Format);
+				g_print ("dvd_data.titles[ %02d ].audio[ %02d ].Frequency: %d\n",
+					title_actif +1,
+					audio_actif +1,
+					dvd_data.titles[ title_actif ].audio[ audio_actif ].Frequency);
+				g_print ("dvd_data.titles[ %02d ].audio[ %02d ].Quantization: %s\n",
+					title_actif +1,
+					audio_actif +1,
+					dvd_data.titles[ title_actif ].audio[ audio_actif ].Quantization);
+				g_print ("dvd_data.titles[ %02d ].audio[ %02d ].Channels: %d\n",
+					title_actif +1,
+					audio_actif +1,
+					dvd_data.titles[ title_actif ].audio[ audio_actif ].Channels);
+				g_print ("dvd_data.titles[ %02d ].audio[ %02d ].StreamId: %s\n",
+					title_actif +1,
+					audio_actif +1,
+					dvd_data.titles[ title_actif ].audio[ audio_actif ].StreamId);
+			}
 		}
 	}
-
 }
 
 void dvdread_remove (void)
@@ -530,7 +528,6 @@ void dvdread_create_recap_audio (void)
 	gint          cpt;
 	gchar        *LineCommand = NULL;
 	FILE         *fp = NULL;
-	gint          Dummy;
 
 	// Suppression du fichier precedant si il existe
 	g_unlink ("/tmp/get_infos_dvd.sh");
@@ -558,9 +555,9 @@ void dvdread_create_recap_audio (void)
 
 	fclose (fp);
 
-	Dummy = system ("chmod +x /tmp/get_infos_dvd.sh");
+	system ("chmod +x /tmp/get_infos_dvd.sh");
 
-	Dummy = system ("/tmp/get_infos_dvd.sh");
+	system ("/tmp/get_infos_dvd.sh");
 	g_unlink ("/tmp/get_infos_dvd.sh");
 }
 
@@ -621,7 +618,6 @@ void dvdread_read_info_audio (void)
 	gint          line;
 	gchar        *ptr = NULL;
 	gint          nmr_title = -1;
-	gint          max_audio = 0;
 	gint          t, a;
 
 	LIST_AUDIO   *list_audio = NULL;
@@ -681,7 +677,7 @@ void dvdread_read_info_audio (void)
 			nmr_title = -1;
 		}
 	}
-	max_audio = 0;
+
 	list = g_list_first (GListAudio);
 	while (list) {
 		if ((list_audio = (LIST_AUDIO *)list->data)) {
