@@ -509,7 +509,6 @@ typedef struct {
 	GtkWidget		*Adr_TreeView;				// Adresse
 	GtkWidget		*Adr_Entry_Dest;			// Adresse
 	GdkPixbuf		*Pixbuf_NotInstall;			// not_install.png
-	gboolean		 BOOL_ENTER_SPIN;			// Because appel crash
 	GtkCellRenderer		*Renderer;
 	GtkTreeViewColumn	*Adr_ColumnFileWavHertz;
 	GtkTreeViewColumn	*Adr_ColumnFileWavVoie;
@@ -518,9 +517,6 @@ typedef struct {
 	GtkTreeViewColumn	*Adr_ColumnFileWavNewVoie;
 	GtkTreeViewColumn	*Adr_ColumnFileWavNewBits;
 	GtkTreeViewColumn	*Adr_ColumnFileWavName;
-	GtkSpinButton		*Adr_spinbutton_frequence;		// 
-	GtkComboBox		*Adr_combobox_voie;			// 
-	GtkComboBox		*Adr_combobox_bit;			// 
 	
 } VAR_FILE_WAV;
 
@@ -543,12 +539,6 @@ typedef struct {
 	GtkTreeViewColumn	*Adr_ColumnFileMp3OggSize;
 	GtkTreeViewColumn	*Adr_ColumnFileMp3OggTime;
 	GtkTreeViewColumn	*Adr_ColumnFileMp3OggName;
-	// GtkComboBox		*Adr_Widget_Lame_abr_cbr_vbr;
-	// GtkComboBox		*Adr_Widget_Lame_bitrate;		
-	// GtkComboBox		*Adr_Widget_Lame_Mode;
-	// GtkComboBox		*Adr_Widget_Oggenc_bitrate;
-	// GtkComboBox		*Adr_Widget_Oggenc_managed;
-	// GtkComboBox		*Adr_Widget_Oggenc_downmix;
 } VAR_FILE_MP3OGG;
 
 extern VAR_FILE_MP3OGG var_file_mp3ogg;
@@ -596,11 +586,8 @@ typedef enum {
 	FILE_TRASH_SELECT_V,
 	// SELECTION ou DESELECTION POUR TRASH
 	FILEWAV_FREQUENCY_CELL_HERTZ,
-	FILEWAV_FREQUENCY_COL_HERTZ,
 	FILEWAV_TRACK_CELL,
-	FILEWAV_TRACK_COL,
-	FILEWAV_QUANTIFICATION_CELL,
-	FILEWAV_QUANTIFICATION_COL
+	FILEWAV_QUANTIFICATION_CELL
 } TYPE_SET_FROM_POPUP_FILE;
 
 // 
@@ -655,7 +642,8 @@ void		FileMp3Ogg_set_flag_buttons( void );
 void		FileMp3Ogg_affiche_glist( void );
 gboolean	FileMp3Ogg_del_file_clicked( void );
 void		FileMp3Ogg_change_parameters( void );
-void		FileMp3Ogg_update_newbitrate( TYPE_FILE_IS p_TypeFileIs );
+// void		FileMp3Ogg_update_newbitrate( TYPE_FILE_IS p_TypeFileIs );
+void		FileMp3Ogg_update_newbitrate( TYPE_FILE_IS p_TypeFileIs, gint p_debit, gint p_mode_managed, gint p_downmix );
 // 
 // ---------------------------------------------------------------------------
 //  FILE_MP3OGG_CONV.C
