@@ -75,7 +75,6 @@
 #include "replaygain.h"
 #include "win_scan.h"
 #include "normalise.h"
-#include "popup_systray.h"
 #include "notify_send.h"
 
 
@@ -177,7 +176,6 @@ static gint fileaction_timeout (gpointer data)
 	    FALSE == FileAction.bool_ReplaygainApply &&
 	    FALSE == FileAction.bool_trash) {
 		
-		PopupSystray_set_BoolMainAction (FALSE);
 		WindScan_close ();
 		gtk_timeout_remove (FileAction.handler_timeout);
 		
@@ -231,8 +229,6 @@ void fileaction_choice (void)
 	FileAction.bool_ReplaygainApply    = file_get_bool_ReplaygainApply ();
 	FileAction.bool_trash              = filetrash_ok ();
 		
-	PopupSystray_set_BoolMainAction (TRUE);
-	
 	FileAction.handler_timeout = gtk_timeout_add (150, fileaction_timeout, 0);
 }
 
