@@ -54,7 +54,6 @@
 #include "win_scan.h"
 #include "prg_init.h"
 #include "win_info.h"
-#include "popup_systray.h"
 #include "file.h"
 
 
@@ -607,7 +606,6 @@ static gint fileanalyze_timeout (gpointer data)
 	}
 	else if (FALSE == VarAnalyze.BoolInThread) {
 		WindScan_close ();
-		PopupSystray_set_BoolMainAction (FALSE);
 		gtk_timeout_remove (VarAnalyze.HandlerTimeoutDo);
 		file_affiche_glist ();
 		FileWav_affiche_glist ();
@@ -658,8 +656,6 @@ void fileanalyze_add_file_to_treeview (TYPE_FILESELECTION p_TypeFileselection, G
 	VarAnalyze.BoolSetPercent = FALSE;
 	VarAnalyze.BoolNoFindCheckMp3 = FALSE;
 	
-	PopupSystray_set_BoolMainAction (TRUE);
-	
 	pthread_create (&nmr_tid_1, NULL ,(void *)fileanalyze_thread, (void *)NULL);
 	VarAnalyze.HandlerTimeoutDo = gtk_timeout_add (100, fileanalyze_timeout, 0);
 }
