@@ -56,7 +56,30 @@
 
 
 
-VAR_FILE_MP3OGG var_file_mp3ogg;
+/*
+typedef struct {
+	GtkWidget		*Adr_scroll;				// Adresse
+	GtkListStore		*Adr_List_Store;			// Adresse
+	GtkTreeModel		*Adr_Tree_Model;			// Adresse
+	GtkTreeSelection	*Adr_Line_Selected;			// Adresse
+	GtkWidget		*Adr_TreeView;				// Adresse
+	GtkWidget		*Adr_Entry_Dest;			// Adresse
+	GtkWidget		*Adr_Button_Dest;			// Adresse
+	GtkComboBox		*Adr_combobox_DestFile;			// Adresse
+	GdkPixbuf		*Pixbuf_NotInstall;			// not_install.png
+	GtkCellRenderer		*Renderer;
+	GtkTreeViewColumn	*Adr_ColumnFileMp3OggType;
+	GtkTreeViewColumn	*Adr_ColumnFileMp3OggBitrate;
+	GtkTreeViewColumn	*Adr_ColumnFileMp3OggNewBitrate;
+	GtkTreeViewColumn	*Adr_ColumnFileMp3OggSize;
+	GtkTreeViewColumn	*Adr_ColumnFileMp3OggTime;
+	GtkTreeViewColumn	*Adr_ColumnFileMp3OggName;
+	gboolean		BoolPopUpIsSelected;			// 
+} VAR_FILE_MP3OGG;
+*/
+VAR_FILE_MP3OGG var_file_mp3ogg = {
+	NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL
+};
 
 enum
 {
@@ -66,7 +89,7 @@ enum
 	COLUMN_FILEMP3OGG_SIZE,
 	COLUMN_FILEMP3OGG_TIME,
 	COLUMN_FILEMP3OGG_NAME,
-	
+	COLUMN_FILEMP3OGG_COLOR,
 	COLUMN_FILEMP3OGG_POINTER_STRUCT,
 
 	COLUMN_FILE_NUM
@@ -354,7 +377,7 @@ gboolean FileMp3Ogg_del_file_clicked (void)
 }
 // UPDATE NEW BITRATE
 // 
-void FileMp3Ogg_update_newbitrate( TYPE_FILE_IS p_TypeFileIs )
+void FileMp3Ogg_update_newbitrate( TYPE_FILE_IS p_TypeFileIs, gint p_debit, gint p_mode_managed, gint p_downmix )
 {
 	GtkTreeModel		*model = NULL;
 	GList			*list = NULL;
@@ -366,7 +389,7 @@ void FileMp3Ogg_update_newbitrate( TYPE_FILE_IS p_TypeFileIs )
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW(var_file_mp3ogg.Adr_TreeView));
 	list = g_list_first (gtk_tree_selection_get_selected_rows (var_file_mp3ogg.Adr_Line_Selected, &model));
 	while (list) {
-		if ((path = list->data)) {
+		if (NULL != (path = list->data)) {
 			gtk_tree_model_get_iter (model, &iter, path);
 			gtk_tree_model_get (var_file_mp3ogg.Adr_Tree_Model, &iter, COLUMN_FILEMP3OGG_POINTER_STRUCT, &detail, -1);
 			
@@ -376,7 +399,11 @@ void FileMp3Ogg_update_newbitrate( TYPE_FILE_IS p_TypeFileIs )
 			}
 			// FILE_IS_MP3
 			if (FILE_IS_MP3 == p_TypeFileIs && FILE_IS_MP3 == detail->type_infosong_file_is) {
-				Str = popup_get_param_mp3( detail->Mp3_Debit, detail->Mp3_Mode );
+				
+				// Str = popup_get_param_mp3( detail->Mp3_Debit, detail->Mp3_Mode );
+				detail->Mp3_Debit = p_debit;
+				detail->Mp3_Mode  = p_mode_managed;
+				Str = popup_get_param_mp3( p_debit, p_mode_managed );
 				gtk_list_store_set (var_file_mp3ogg.Adr_List_Store, &iter, COLUMN_FILEMP3OGG_NEWBITRATE, Str != NULL ? Str : "", -1);
 				
 				detail->BoolChanged = (Str != NULL) ? TRUE : FALSE;
@@ -387,7 +414,12 @@ void FileMp3Ogg_update_newbitrate( TYPE_FILE_IS p_TypeFileIs )
 			}
 			// FILE_IS_OGG
 			else if (FILE_IS_OGG == p_TypeFileIs && FILE_IS_OGG == detail->type_infosong_file_is) {
-				Str = popup_get_param_ogg( detail->Ogg_Debit, detail->Ogg_Managed, detail->Ogg_Downmix );
+				
+				// Str = popup_get_param_ogg( detail->Ogg_Debit, detail->Ogg_Managed, detail->Ogg_Downmix );
+				detail->Ogg_Debit   = p_debit;
+				detail->Ogg_Managed = p_mode_managed;
+				detail->Ogg_Downmix = p_downmix;
+				Str = popup_get_param_ogg( p_debit, p_mode_managed, p_downmix );
 				gtk_list_store_set (var_file_mp3ogg.Adr_List_Store, &iter, COLUMN_FILEMP3OGG_NEWBITRATE, Str != NULL ? Str : "", -1);
 				
 				detail->BoolChanged = (Str != NULL) ? TRUE : FALSE;
@@ -421,7 +453,6 @@ void FileMp3Ogg_affiche_glist (void)
 	gchar		*PtrBitrate = NULL;
 	gchar		*NameDest = NULL;
 
-	
 	// LIBERATION LIGNE(S) DU GLIST SI NECESSARE
 	// 
 	List = g_list_first (entetefile);
@@ -492,6 +523,7 @@ void FileMp3Ogg_affiche_glist (void)
 						COLUMN_FILEMP3OGG_SIZE,			file_get_size (detail),
 						COLUMN_FILEMP3OGG_TIME,			file_get_time (detail),
 						COLUMN_FILEMP3OGG_NAME,			NameDest,
+						COLUMN_FILEMP3OGG_COLOR,		&YellowColor,
 						COLUMN_FILEMP3OGG_POINTER_STRUCT,	detail,
 						-1);
 			
@@ -570,7 +602,6 @@ void on_filemp3ogg_button_efface_bitrate_clicked (GtkButton *button, gpointer us
 void FileMp3Ogg_changed_selection_row (GtkTreeSelection *selection, gpointer data)
 {	
 	var_file_mp3ogg.Adr_Line_Selected = selection;
-	
 	FileMp3Ogg_set_flag_buttons ();
 }
 // 
@@ -728,13 +759,14 @@ gboolean FileMp3Ogg_event_click_mouse( GtkWidget *treeview, GdkEventButton *even
 {
 	GtkTreePath        *path;
 	GtkTreeViewColumn  *column;
-	// GtkTreeViewColumn  *ColumnDum;
 	GtkTreeIter         iter;
 	GtkTreeModel       *model = (GtkTreeModel *)data;
 	DETAIL             *detail = NULL;
 	gint                Pos_X = 0, Pos_Y = 0;
 	gboolean            bool_click_droit = (event->button == 3);	
 	
+	
+	
 	/* Single clicks only */
 	if (event->type != GDK_BUTTON_PRESS) return (FALSE);
 	
@@ -742,20 +774,61 @@ gboolean FileMp3Ogg_event_click_mouse( GtkWidget *treeview, GdkEventButton *even
 	if (FALSE == gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW(treeview),
 					  (gint)event->x, (gint)event->y,
 					   &path, &column, &Pos_X, &Pos_Y)) return (FALSE);
-	// RECCPERATION DE LA STRUCTURE
+
+	// RECUP DE LA STRUCTURE
 	gtk_tree_model_get_iter (model, &iter, path);
 	gtk_tree_model_get (var_file_mp3ogg.Adr_Tree_Model, &iter, COLUMN_FILEMP3OGG_POINTER_STRUCT, &detail, -1);
 	if (NULL == detail) return (FALSE);
 	
+	/*-----------------*/
+	/*if( (bool_click_droit) && (FILE_IS_MP3 == detail->type_infosong_file_is || FILE_IS_OGG == detail->type_infosong_file_is) )
+	{
+		GtkTreeSelection *selection;
+
+		selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
+
+		if (gtk_tree_selection_count_selected_rows(selection)  <= 1)
+		{
+			GtkTreePath *path;
+
+			
+			if (gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(treeview),
+							(gint) event->x, 
+							(gint) event->y,
+							&path, NULL, NULL, NULL))
+			{
+				gtk_tree_selection_unselect_all(selection);
+				gtk_tree_selection_select_path(selection, path);
+				gtk_tree_path_free(path);
+			}
+		}
+	}
+	*/
+	
+	/*-----------------*/
 	if( bool_click_droit && FILE_IS_MP3 == detail->type_infosong_file_is )
 	{
 		// DEBIT MODE
 		popup_file_mp3_type( detail, detail->Mp3_Debit, detail->Mp3_Mode );
+		
+		// AUTORISE LE POPUP SUR UNE SELECTION MULTIPLE
+		var_file_mp3ogg.Adr_Line_Selected = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
+		gtk_tree_selection_select_path(var_file_mp3ogg.Adr_Line_Selected, path);
+		// gtk_tree_path_free(path);
+		return TRUE;
+		
 	}
 	else if( bool_click_droit && FILE_IS_OGG == detail->type_infosong_file_is )
 	{
 		// DEBIT MANAGED DOWNMIX
 		popup_file_ogg_type( detail, detail->Ogg_Debit, detail->Ogg_Managed, detail->Ogg_Downmix );
+		
+		var_file_mp3ogg.Adr_Line_Selected = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
+		// AUTORISE LE POPUP SUR UNE SELECTION MULTIPLE
+		gtk_tree_selection_select_path(var_file_mp3ogg.Adr_Line_Selected, path);
+		// gtk_tree_path_free(path);
+		return TRUE;
+		
 	}
 	
 	return (FALSE);
@@ -785,7 +858,7 @@ static void FileMp3Ogg_add_columns_scrolledwindow (GtkTreeView *treeview)
 	g_signal_connect(G_OBJECT(var_file_mp3ogg.Adr_Line_Selected),
 			 "changed",
                    	 G_CALLBACK(FileMp3Ogg_changed_selection_row),
-                   	 "1");
+                   	 model);
 	
 	// SIGNAL 'key-press-event'
 	g_signal_connect(G_OBJECT(treeview),
@@ -902,6 +975,7 @@ static void FileMp3Ogg_add_columns_scrolledwindow (GtkTreeView *treeview)
 	column = gtk_tree_view_column_new_with_attributes (_("Nom"),
 						     renderer,
 						     "markup", COLUMN_FILEMP3OGG_NAME,
+						      "background-gdk", COLUMN_FILEMP3OGG_COLOR,
 						     NULL);
 	gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN (column),
 				   GTK_TREE_VIEW_COLUMN_FIXED);
@@ -922,13 +996,14 @@ void on_scrolledwindow_file_mp3ogg_realize (GtkWidget *widget, gpointer user_dat
 	var_file_mp3ogg.Pixbuf_NotInstall		= libutils_init_pixbufs ("xcfa/not_install.png");
 	
 	var_file_mp3ogg.Adr_List_Store = store =
-	gtk_list_store_new (	COLUMN_FILE_NUM,	/* TOTAL NUMBER			*/
-				G_TYPE_STRING,		/* COLUMN_FILEMP3OGG_TYPE	*/
-				G_TYPE_STRING,		/* COLUMN_FILEMP3OGG_BITRATE	*/
-				G_TYPE_STRING,		/* COLUMN_FILEMP3OGG_NEWBITRATE	*/
-				G_TYPE_STRING,		/* COLUMN_FILEMP3OGG_SIZE	*/
-				G_TYPE_STRING,		/* COLUMN_FILEMP3OGG_TIME	*/
-				G_TYPE_STRING,		/* COLUMN_FILEMP3OGG_NAME	*/
+	gtk_list_store_new (	COLUMN_FILE_NUM,	/* TOTAL NUMBER				*/
+				G_TYPE_STRING,		/* COLUMN_FILEMP3OGG_TYPE		*/
+				G_TYPE_STRING,		/* COLUMN_FILEMP3OGG_BITRATE		*/
+				G_TYPE_STRING,		/* COLUMN_FILEMP3OGG_NEWBITRATE		*/
+				G_TYPE_STRING,		/* COLUMN_FILEMP3OGG_SIZE		*/
+				G_TYPE_STRING,		/* COLUMN_FILEMP3OGG_TIME		*/
+				G_TYPE_STRING,		/* COLUMN_FILEMP3OGG_NAME		*/
+				GDK_TYPE_COLOR,		/* COLUMN_FILEMP3OGG_COLOR		*/
 				G_TYPE_POINTER          /* COLUMN_FILEMP3OGG_POINTER_STRUCT	*/
 			   );
 	var_file_mp3ogg.Adr_Tree_Model = model = GTK_TREE_MODEL (store);
