@@ -53,7 +53,6 @@
 #include "prg_init.h"
 #include "win_scan.h"
 #include "win_info.h"
-#include "popup_systray.h"
 #include "popup.h"
 #include "file.h"
 
@@ -321,8 +320,6 @@ static gint filemp3oggconv_timeout (gpointer data)
 			conv.TmpRep  = libutils_remove_temporary_rep (conv.TmpRep);
 		}
 
-		PopupSystray_set_BoolMainAction (FALSE);
-
 		gtk_timeout_remove (conv.handler_timeout_conv);
 		WindScan_close ();
 		FileMp3Ogg_set_flag_buttons ();
@@ -476,8 +473,6 @@ void filemp3oggconv_apply_regul_mp3ogg_by_conv (void)
 		WindScan_open ("Conversions bitrate", WINDSCAN_PULSE);
 		WindScan_set_label ("<b><i>Conversions bitrate ...</i></b>");
 	
-		PopupSystray_set_BoolMainAction (TRUE);
-		
 		BoolErrMplayer = FALSE;
 		BoolErrSox     = FALSE;
 		
