@@ -45,7 +45,6 @@
 #include "configuser.h"
 #include "get_info.h"
 #include "win_scan.h"
-#include "popup_systray.h"
 #include "file.h"
 
 
@@ -201,7 +200,6 @@ static gint FileScanDB_timeout (gpointer data)
 	
 	if (VarFileScanDB.bool_thread_end == TRUE) {
 		if (FALSE == VarFileScanDB.BoolWindScanUsed) WindScan_close ();
-		PopupSystray_set_BoolMainAction (FALSE);
 		gtk_timeout_remove (VarFileScanDB.handler_timeout);
 	}
 	
@@ -223,8 +221,6 @@ void FileScanDB_action (gboolean BoolAllScan)
 		VarFileScanDB.bool_update = FALSE;
 		VarFileScanDB.MessUser = NULL;
 		
-		PopupSystray_set_BoolMainAction (TRUE);
-	
 		VarFileScanDB.BoolWindScanUsed = WindScan_open ("Scan dBFS", WINDSCAN_PULSE);
 		VarFileScanDB.handler_timeout = gtk_timeout_add (50, FileScanDB_timeout, 0);
 		pthread_create (&VarFileScanDB.nmr_tid, NULL ,(void *)FileScanDB_thread, (void *)NULL);
