@@ -67,6 +67,7 @@ enum
 	COLUMN_FILETAGS_TYPE = 0,
 	COLUMN_FILETAGS_TIME,
 	COLUMN_FILETAGS_NAME,
+	COLUMN_FILETAGS_COLOR,
 	
 	COLUMN_FILETAGS_POINTER_STRUCT,
 
@@ -907,6 +908,7 @@ void FileTags_affiche_glist (void)
 						COLUMN_FILETAGS_TYPE,		tags_get_str_type_file_is (detail->type_infosong_file_is),
 						COLUMN_FILETAGS_TIME,		file_get_time (detail),
 						COLUMN_FILETAGS_NAME,		NameDest,
+						COLUMN_FILETAGS_COLOR,		&YellowColor,
 						COLUMN_FILETAGS_POINTER_STRUCT,	detail,
 						-1);
 						
@@ -1204,6 +1206,7 @@ void FileTags_add_columns_scrolledwindow (GtkTreeView *treeview)
 	column = gtk_tree_view_column_new_with_attributes (_("Nom"),
 						     renderer,
 						     "markup", COLUMN_FILETAGS_NAME,
+						      "background-gdk", COLUMN_FILETAGS_COLOR,
 						     NULL);
 	gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN (column),
 				   GTK_TREE_VIEW_COLUMN_FIXED);
@@ -1227,6 +1230,7 @@ void on_scrolledwindow_tags_file_realize (GtkWidget *widget, gpointer user_data)
 				G_TYPE_STRING,		// COLUMN_FILETAGS_TYPE
 				G_TYPE_STRING,		// COLUMN_FILETAGS_TIME
 				G_TYPE_STRING,		// COLUMN_FILETAGS_NAME
+				GDK_TYPE_COLOR,		// COLUMN_FILETAGS_COLOR
 				G_TYPE_POINTER          // COLUMN_FILETAGS_POINTER_STRUCT
 			   );
 	var_file_tags.Adr_Tree_Model = model = GTK_TREE_MODEL (store);
