@@ -67,6 +67,7 @@ enum
 	COLUMN_FILEWAV_BITS,
 	COLUMN_FILEWAV_NEW_BITS,
 	COLUMN_FILEWAV_NAME,
+	COLUMN_FILEWAV_COLOR,
 	
 	COLUMN_FILEWAV_POINTER_STRUCT,
 
@@ -133,9 +134,9 @@ void FileWav_set_flag_buttons (void)
 	BoolButtonsAudio [ 2 ] = FileWav_get_bool_conversion ();
 
 	gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("button_del_file")),		BoolButtonsAudio [ 0 ]);
-	gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("spinbutton_frequence_wav")),	BoolButtonsAudio [ 1 ]);
-	gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("combobox_voie_wav")),		BoolButtonsAudio [ 1 ]);
-	gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("combobox_bit_wav")),		BoolButtonsAudio [ 1 ]);
+	// gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("spinbutton_frequence_wav")),	BoolButtonsAudio [ 1 ]);
+	// gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("combobox_voie_wav")),		BoolButtonsAudio [ 1 ]);
+	// gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("combobox_bit_wav")),		BoolButtonsAudio [ 1 ]);
 	gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("button_apply_wav")),		BoolButtonsAudio [ 2 ]);
 }
 // CHANGEMENT DES PARAMETRES: freq, voie, bits SI PARAM <> NULL
@@ -287,6 +288,7 @@ void FileWav_affiche_glist (void)
 						COLUMN_FILEWAV_BITS,		info->bits,
 						COLUMN_FILEWAV_NEW_BITS,	NewBits,
 						COLUMN_FILEWAV_NAME,		NameDest,
+						COLUMN_FILEWAV_COLOR,		&YellowColor,
 						COLUMN_FILEWAV_POINTER_STRUCT,	detail,
 						-1);
 									
@@ -326,13 +328,6 @@ void FileWav_affiche_glist (void)
 
 	FileWav_set_flag_buttons ();
 }
-// 
-// 
-void on_spinbutton_frequence_wav_realize (GtkWidget *widget, gpointer user_data)
-{
-	var_file_wav.Adr_spinbutton_frequence = GTK_SPIN_BUTTON (widget);
-	gtk_widget_set_sensitive (GTK_WIDGET (GTK_SPIN_BUTTON (var_file_wav.Adr_spinbutton_frequence)), FALSE);
-}
 // CHANGEMENT DES PARAMETRES: freq, voie, ou bits SI <> DE NULL
 // 
 void FileWav_set_change_parameters_is_selected (gchar *freq, gchar *voie, gchar *bits)
@@ -382,9 +377,6 @@ void FileWav_set_change_parameters_is_selected (gchar *freq, gchar *voie, gchar
 				else	Str = g_strdup_printf ("<span color=\"red\"><b>%s</b></span>", info->NewHertz);
 				gtk_list_store_set (var_file_wav.Adr_List_Store, &iter, COLUMN_FILEWAV_NEW_HERTZ, Str, -1);
 				g_free (Str);	Str = NULL;
-				var_file_wav.BOOL_ENTER_SPIN = FALSE;
-				gtk_spin_button_set_value (GTK_SPIN_BUTTON (var_file_wav.Adr_spinbutton_frequence), (gdouble)atoi(info->NewHertz));
-				var_file_wav.BOOL_ENTER_SPIN = TRUE;
 			}
 			if (NULL != voie) {
 				if (info->NewVoie) {
@@ -403,16 +395,6 @@ void FileWav_set_change_parameters_is_selected (gchar *freq, gchar *voie, gchar
 				else	Str = g_strdup_printf ("<span color=\"red\"><b>%s</b></span>", info->NewVoie);
 				gtk_list_store_set (var_file_wav.Adr_List_Store, &iter, COLUMN_FILEWAV_NEW_VOIE, Str, -1);
 				g_free (Str);	Str = NULL;
-				
-				var_file_wav.BOOL_ENTER_SPIN = FALSE;
-				switch (atoi(info->NewVoie)) {
-				case 1  : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_voie), 0);	break;
-				case 2  : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_voie), 1);	break;
-				case 4  : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_voie), 2);	break;
-				case 6  : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_voie), 3);	break;
-				default : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_voie), 4);
-				}
-				var_file_wav.BOOL_ENTER_SPIN = TRUE;
 			}
 			if (NULL != bits) {
 				if (info->NewBits) {
@@ -431,18 +413,6 @@ void FileWav_set_change_parameters_is_selected (gchar *freq, gchar *voie, gchar
 				else	Str = g_strdup_printf ("<span color=\"red\"><b>%s</b></span>", info->NewBits);
 				gtk_list_store_set (var_file_wav.Adr_List_Store, &iter, COLUMN_FILEWAV_NEW_BITS, Str, -1);
 				g_free (Str);	Str = NULL;
-				
-				var_file_wav.BOOL_ENTER_SPIN = FALSE;
-				switch (atoi(info->NewBits)) {
-				case 8  : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_bit), 0);	break;
-				case 16 : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_bit), 1);	break;
-				case 24 : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_bit), 2);	break;
-				case 25 : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_bit), 3);	break;
-				case 32 : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_bit), 4);	break;
-				case 64 : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_bit), 5);	break;
-				default : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_bit), 0);
-				}
-				var_file_wav.BOOL_ENTER_SPIN = TRUE;
 			}
 			
 			info->BoolConv = FALSE;
@@ -459,103 +429,9 @@ void FileWav_set_change_parameters_is_selected (gchar *freq, gchar *voie, gchar
 }
 // 
 // 
-void on_filewav_spinbutton_frequence_value_changed (GtkSpinButton *spinbutton, gpointer user_data)
-{
-	gchar  *ptr = NULL;
-	glong   value;
-
-	if (NULL == var_file_wav.Adr_spinbutton_frequence) return;
-	if (FALSE == var_file_wav.BOOL_ENTER_SPIN) return;
-
-	value = (glong)gtk_spin_button_get_value (var_file_wav.Adr_spinbutton_frequence);
-
-	if (value == 0) {
-		FileWav_set_change_parameters_is_selected ("", NULL, NULL);
-	}
-	else {
-		ptr = g_strdup_printf ("%lu", value);
-		FileWav_set_change_parameters_is_selected (ptr, NULL, NULL);
-		g_free (ptr);
-		ptr = NULL;
-	}
-	FileWav_set_flag_buttons ();
-}
-// 
-// 
-void FileWav_get_new_frequence (glong *p_Frequence, gint *p_Voie, gint *p_Bit)
-{
-	GtkTreeIter       iter;
-	GtkTreeModel     *model = NULL;
-	GList            *list = NULL;
-	GList            *BeginList = NULL;
-	GtkTreePath      *path;
-	DETAIL           *detail = NULL;
-	INFO_WAV	 *info = NULL;
-	
-	*p_Frequence = -1;
-	*p_Voie      = -1;
-	*p_Bit       = -1;
-	
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW(var_file_wav.Adr_TreeView));
-	if (NULL != (BeginList = gtk_tree_selection_get_selected_rows (var_file_wav.Adr_Line_Selected, &model))) {
-		list = g_list_first (BeginList);
-		while (list) {
-			if (NULL != (path = list->data)) {
-				gtk_tree_model_get_iter (model, &iter, path);
-				gtk_tree_model_get (var_file_wav.Adr_Tree_Model, &iter, COLUMN_FILEWAV_POINTER_STRUCT, &detail, -1);
-				if (NULL != detail && NULL != (info = (INFO_WAV *)detail->info)) {
-					*p_Frequence = (glong)atol (info->NewHertz);
-					*p_Voie      = (gint)atoi (info->NewVoie);
-					*p_Bit       = (gint)atoi (info->NewBits);
-					return;
-				}
-			}
-			list = g_list_next (list);
-		}
-	}
-}
-// 
-// 
 void FileWav_changed_selection_row (GtkTreeSelection *selection, gpointer data)
 {
 	var_file_wav.Adr_Line_Selected = selection;
-	
-	if (NOTEBOOK_FICHIERS == Config.NotebookGeneral && NOTEBOOK_FICHIERS_WAV == Config.NotebookFile) {
-		if (NULL != var_file_wav.Adr_spinbutton_frequence) {
-			glong Frequence;
-			gint Voie;
-			gint Bit;
-			
-			FileWav_get_new_frequence (&Frequence, &Voie, &Bit);
-			if (-1 != Frequence && -1 != Voie && -1 != Bit) {
-
-				var_file_wav.BOOL_ENTER_SPIN = FALSE;
-				
-				gtk_spin_button_set_value (GTK_SPIN_BUTTON (var_file_wav.Adr_spinbutton_frequence), 1.0);
-				gtk_spin_button_set_value (GTK_SPIN_BUTTON (var_file_wav.Adr_spinbutton_frequence), Frequence);
-				
-				switch (Voie) {
-				case 1  : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_voie), 0);	break;
-				case 2  : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_voie), 1);	break;
-				case 4  : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_voie), 2);	break;
-				case 6  : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_voie), 3);	break;
-				default : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_voie), 4);
-				}
-				
-				switch (Bit) {
-				case 8  : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_bit), 0);	break;
-				case 16 : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_bit), 1);	break;
-				case 24 : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_bit), 2);	break;
-				case 25 : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_bit), 3);	break;
-				case 32 : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_bit), 4);	break;
-				case 64 : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_bit), 5);	break;
-				default : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_bit), 0);
-				}
-				
-				var_file_wav.BOOL_ENTER_SPIN = TRUE;
-			}
-		}
-	}
 	FileWav_set_flag_buttons ();
 }
 // AFFICHAGE DU NOM COMPLET DU FICHIER SI SURVOL PAR LE CURSEUR SOURIS DU CHAMPS 'Nom'
@@ -781,13 +657,31 @@ gboolean FileWav_event_click_mouse (GtkWidget *treeview, GdkEventButton *event,
 	}
 	
 	if (bool_click_droit && BoolSelectColFREQUENCE) {
+		
 		popup_file_wav_frequence (detail);
+
+		// AUTORISE LE POPUP SUR UNE SELECTION MULTIPLE
+		var_file_wav.Adr_Line_Selected = gtk_tree_view_get_selection( GTK_TREE_VIEW(treeview) );
+		gtk_tree_selection_select_path( var_file_wav.Adr_Line_Selected, path );
+		return TRUE;
 	}
 	else if (bool_click_droit && BoolSelectColPISTE) {
+		
 		popup_file_wav_piste (detail);
+
+		// AUTORISE LE POPUP SUR UNE SELECTION MULTIPLE
+		var_file_wav.Adr_Line_Selected = gtk_tree_view_get_selection( GTK_TREE_VIEW(treeview) );
+		gtk_tree_selection_select_path( var_file_wav.Adr_Line_Selected, path );
+		return TRUE;
 	}
 	else if (bool_click_droit && BoolSelectColQUANTIFICATION) {
+		
 		popup_file_wav_quantification (detail);
+
+		// AUTORISE LE POPUP SUR UNE SELECTION MULTIPLE
+		var_file_wav.Adr_Line_Selected = gtk_tree_view_get_selection( GTK_TREE_VIEW(treeview) );
+		gtk_tree_selection_select_path( var_file_wav.Adr_Line_Selected, path );
+		return TRUE;
 	}
 
 	return (FALSE);
@@ -947,6 +841,7 @@ static void FileWav_add_columns_scrolledwindow (GtkTreeView *treeview)
 	column = gtk_tree_view_column_new_with_attributes (_("Nom"),
 						     renderer,
 						     "markup", COLUMN_FILEWAV_NAME,
+						      "background-gdk", COLUMN_FILEWAV_COLOR,
 						     NULL);
 	gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN (column),
 				   GTK_TREE_VIEW_COLUMN_FIXED);
@@ -968,14 +863,15 @@ void on_scrolledwindow_file_wav_realize (GtkWidget *widget, gpointer user_data)
 	var_file_wav.Pixbuf_NotInstall             = libutils_init_pixbufs ("not_install.png");
 	
 	var_file_wav.Adr_List_Store = store =
-	gtk_list_store_new (	COLUMN_FILE_NUM,	/* TOTAL NUMBER			*/
-				G_TYPE_STRING,		/* COLUMN_FILEWAV_HERTZ		*/
-				G_TYPE_STRING,		/* COLUMN_FILEWAV_NEW_HERTZ	*/
-				G_TYPE_STRING,		/* COLUMN_FILEWAV_VOIE		*/
-				G_TYPE_STRING,		/* COLUMN_FILEWAV_NEW_VOIE	*/
-				G_TYPE_STRING,		/* COLUMN_FILEWAV_BITS		*/
-				G_TYPE_STRING,		/* COLUMN_FILEWAV_NEW_BITS	*/
-				G_TYPE_STRING,		/* COLUMN_FILEWAV_NAME		*/
+	gtk_list_store_new (	COLUMN_FILE_NUM,	/* TOTAL NUMBER				*/
+				G_TYPE_STRING,		/* COLUMN_FILEWAV_HERTZ			*/
+				G_TYPE_STRING,		/* COLUMN_FILEWAV_NEW_HERTZ		*/
+				G_TYPE_STRING,		/* COLUMN_FILEWAV_VOIE			*/
+				G_TYPE_STRING,		/* COLUMN_FILEWAV_NEW_VOIE		*/
+				G_TYPE_STRING,		/* COLUMN_FILEWAV_BITS			*/
+				G_TYPE_STRING,		/* COLUMN_FILEWAV_NEW_BITS		*/
+				G_TYPE_STRING,		/* COLUMN_FILEWAV_NAME			*/
+				GDK_TYPE_COLOR,		/* COLUMN_FILEWAV_COLOR			*/
 				G_TYPE_POINTER          /* COLUMN_FILEWAV_POINTER_STRUCT	*/
 			   );
 	var_file_wav.Adr_Tree_Model = model = GTK_TREE_MODEL (store);
@@ -990,245 +886,16 @@ void on_scrolledwindow_file_wav_realize (GtkWidget *widget, gpointer user_data)
 }
 // 
 // 
-void on_combobox_voie_wav_realize (GtkWidget *widget, gpointer user_data)
-{
-	libcombo_alloc (GTK_COMBO_BOX (widget));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "1");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "2");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "4");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "6");
-	// gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "--");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Valeur d'origine");
-	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
-	var_file_wav.Adr_combobox_voie = GTK_COMBO_BOX (widget);
-	gtk_widget_set_sensitive (GTK_WIDGET (var_file_wav.Adr_combobox_voie), FALSE);
-}
-// 
-// 
-void on_combobox_voie_wav_changed (GtkComboBox *combobox, gpointer user_data)
-{
-	gint	Voie;
-	
-	if (NULL == var_file_wav.Adr_combobox_voie) return;
-	if (FALSE == var_file_wav.BOOL_ENTER_SPIN) return;
-	
-	Voie = gtk_combo_box_get_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_voie));
-	switch (Voie) {
-	case 0 : FileWav_set_change_parameters_is_selected (NULL, "1", NULL);	break;
-	case 1 : FileWav_set_change_parameters_is_selected (NULL, "2", NULL);	break;
-	case 2 : FileWav_set_change_parameters_is_selected (NULL, "4", NULL);	break;
-	case 3 : FileWav_set_change_parameters_is_selected (NULL, "6", NULL);	break;
-	case 4 : FileWav_set_change_parameters_is_selected (NULL, "-1", NULL);	break;
-	}
-	FileWav_set_flag_buttons ();
-}
-// 
-// 
-void on_combobox_bit_wav_realize (GtkWidget *widget, gpointer user_data)
-{
-	libcombo_alloc (GTK_COMBO_BOX (widget));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "8");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "16");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "24");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "25");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "32");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "64");
-	// gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "--");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Valeur d'origine");
-	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
-	var_file_wav.Adr_combobox_bit = GTK_COMBO_BOX (widget);
-	gtk_widget_set_sensitive (GTK_WIDGET (var_file_wav.Adr_combobox_bit), FALSE);
-}
-// 
-// 
-void on_combobox_bit_wav_changed (GtkComboBox *combobox, gpointer user_data)
-{
-	gint	Bit;
-	
-	if (NULL == var_file_wav.Adr_combobox_bit) return;
-	if (FALSE == var_file_wav.BOOL_ENTER_SPIN) return;
-	
-	Bit = gtk_combo_box_get_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_bit));
-	switch (Bit) {
-	case 0 : FileWav_set_change_parameters_is_selected (NULL, NULL, "8");	break;
-	case 1 : FileWav_set_change_parameters_is_selected (NULL, NULL, "16");	break;
-	case 2 : FileWav_set_change_parameters_is_selected (NULL, NULL, "24");	break;
-	case 3 : FileWav_set_change_parameters_is_selected (NULL, NULL, "25");	break;
-	case 4 : FileWav_set_change_parameters_is_selected (NULL, NULL, "32");	break;
-	case 5 : FileWav_set_change_parameters_is_selected (NULL, NULL, "64");	break;
-	case 6 : FileWav_set_change_parameters_is_selected (NULL, NULL, "-1");	break;
-	}
-	FileWav_set_flag_buttons ();
-}
-// 
-// 
-INFO_WAV *FileWav_get_info (void)
-{
-	GtkTreeIter	iter;
-	GtkTreeModel	*model = NULL;
-	GtkTreePath	*path;
-	DETAIL		*detail = NULL;
-	GList		*list = NULL;
-	INFO_WAV	*info = NULL;
-
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW(var_file_wav.Adr_TreeView));
-	list = gtk_tree_selection_get_selected_rows (var_file_wav.Adr_Line_Selected, &model);
-	list = g_list_first (list);
-	while (list) {
-		if (NULL != (path = list->data)) {
-			/* prend le numero de la structure
-			*/
-			gtk_tree_model_get_iter (model, &iter, path);
-			gtk_tree_model_get (var_file_wav.Adr_Tree_Model, &iter, COLUMN_FILEWAV_POINTER_STRUCT, &detail, -1);
-			if (NULL == detail) {
-				list = g_list_next (list);
-				continue;
-			}
-			if (NULL != (info = (INFO_WAV *)detail->info)) return ((INFO_WAV *)info);
-						
-		}
-		list = g_list_next (list);
-	}
-	return ((INFO_WAV *)NULL);
-}
-// 
-// 
-void FileWav_from_popup_set_data_column (gchar *freq, gchar *voie, gchar *bits)
-{
-	GtkTreeIter	iter;
-	DETAIL		*detail = NULL;
-	INFO_WAV	*info = NULL;
-	gboolean	valid;
-	gchar		*Str = NULL;
-	
-	valid = gtk_tree_model_get_iter_first (var_file_wav.Adr_Tree_Model, &iter);
-	while (valid) {
-		gtk_tree_model_get (var_file_wav.Adr_Tree_Model, &iter, COLUMN_FILEWAV_POINTER_STRUCT, &detail, -1);
-		if (NULL != detail && NULL != (info = (INFO_WAV *)detail->info)) {
-			
-			/* Et mettre le contenu a jour
-			*/
-			if (NULL != freq) {
-				if (info->NewHertz) {
-					g_free (info->NewHertz);
-					info->NewHertz = NULL;
-				}
-				// VALEURS PAR DEFAUT
-				if (0 == strcmp (freq, "-1")) {
-					info->NewHertz = g_strdup (info->hertz);
-				} else {
-					info->NewHertz = g_strdup (freq);
-				}
-
-				if (strcmp (info->hertz, info->NewHertz) == 0)
-					Str = g_strdup_printf ("<span color=\"forestgreen\"><b>%s</b></span>", info->NewHertz);
-				else	Str = g_strdup_printf ("<span color=\"red\"><b>%s</b></span>", info->NewHertz);
-				gtk_list_store_set (var_file_wav.Adr_List_Store, &iter, COLUMN_FILEWAV_NEW_HERTZ, Str, -1);
-				g_free (Str);	Str = NULL;
-			}
-			if (NULL != voie) {
-				if (info->NewVoie) {
-					g_free (info->NewVoie);
-					info->NewVoie = NULL;
-				}
-				// VALEURS PAR DEFAUT
-				if (0 == strcmp (voie, "-1")) {
-					info->NewVoie = g_strdup (info->voie);
-				} else {
-					info->NewVoie = g_strdup (voie);
-				}
-
-				if (0 == strcmp (info->voie, info->NewVoie))
-					Str = g_strdup_printf ("<span color=\"forestgreen\"><b>%s</b></span>", info->NewVoie);
-				else	Str = g_strdup_printf ("<span color=\"red\"><b>%s</b></span>", info->NewVoie);
-				gtk_list_store_set (var_file_wav.Adr_List_Store, &iter, COLUMN_FILEWAV_NEW_VOIE, Str, -1);
-				g_free (Str);	Str = NULL;
-				
-			}
-			if (NULL != bits) {
-				if (info->NewBits) {
-					g_free (info->NewBits);
-					info->NewBits = NULL;
-				}
-				// VALEURS PAR DEFAUT
-				if (0 == strcmp (bits, "-1")) {
-					info->NewBits = g_strdup (info->bits);
-				} else {
-					info->NewBits = g_strdup (bits);
-				}
-
-				if (strcmp (info->bits, info->NewBits) == 0)
-					Str = g_strdup_printf ("<span color=\"forestgreen\"><b>%s</b></span>", info->NewBits);
-				else	Str = g_strdup_printf ("<span color=\"red\"><b>%s</b></span>", info->NewBits);
-				gtk_list_store_set (var_file_wav.Adr_List_Store, &iter, COLUMN_FILEWAV_NEW_BITS, Str, -1);
-				g_free (Str);	Str = NULL;
-			}
-			
-			info->BoolConv = FALSE;
-			if ( atoi (info->hertz) != atoi (info->NewHertz) ||
-			     atoi (info->voie) != atoi (info->NewVoie) ||
-			     atoi (info->bits) != atoi (info->NewBits)) {
-			
-				info->BoolConv = TRUE;
-			}
-			
-			
-			valid = gtk_tree_model_iter_next (var_file_wav.Adr_Tree_Model, &iter);
-		}
-	}
-	info = FileWav_get_info ();
-
-	var_file_wav.BOOL_ENTER_SPIN = FALSE;
-	
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (var_file_wav.Adr_spinbutton_frequence), (gdouble)atoi(info->NewHertz));
-
-	switch (atoi(info->NewVoie)) {
-	case 1  : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_voie), 0);	break;
-	case 2  : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_voie), 1);	break;
-	case 4  : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_voie), 2);	break;
-	case 6  : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_voie), 3);	break;
-	default : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_voie), 4);
-	}
-
-	switch (atoi(info->NewBits)) {
-	case 8  : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_bit), 0);	break;
-	case 16 : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_bit), 1);	break;
-	case 24 : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_bit), 2);	break;
-	case 25 : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_bit), 3);	break;
-	case 32 : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_bit), 4);	break;
-	case 64 : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_bit), 5);	break;
-	default : gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_wav.Adr_combobox_bit), 0);
-	}
-
-	var_file_wav.BOOL_ENTER_SPIN = TRUE;
-	
-	FileWav_set_flag_buttons ();
-}
-// 
-// 
-void FileWav_from_popup_set_data (DETAIL *detail, gchar *StrFreq, gchar *StrVoie, gchar *StrBits)
+void FileWav_from_popup_set_data (gchar *StrFreq, gchar *StrVoie, gchar *StrBits)
 {
 	// TRAITEMENT DE LA CELLULE POINTEE PAR LA STRUCTURE DETAIL
-	if (NULL == detail) {
 		
-		// VALEUR PAR DEFAUT SUR LA CELLULE POINTEE PAR LA STRUCTURE DETAIL
-		// 	EX: -1, NULL, NULL
-		// ASSIGNEMENT DU POINTEUR NON NULL SUR LA CELLULE POINTEE PAR LA STRUCTURE DETAIL
-		// 	EX: 44100, NULL, NULL
-		// 
-		FileWav_set_change_parameters_is_selected (StrFreq, StrVoie, StrBits);
-	}
-	
-	// TRAITEMENT DE LA COLONNE ENTIERE
-	else {
-		
-		// VALEUR PAR DEFAUT SUR LA COLONNE ENTIERE
-		// 	EX: -1, NULL, NULL
-		// ASSIGNEMENT DU POINTEUR NON NULL SUR LA COLONNE ENTIERE
-		// 	EX: 44100, NULL, NULL
-		// 
-		FileWav_from_popup_set_data_column (StrFreq, StrVoie, StrBits);
-	}
+	// VALEUR PAR DEFAUT SUR LA CELLULE POINTEE PAR LA STRUCTURE DETAIL
+	// 	EX: -1, NULL, NULL
+	// ASSIGNEMENT DU POINTEUR NON NULL SUR LA CELLULE POINTEE PAR LA STRUCTURE DETAIL
+	// 	EX: 44100, NULL, NULL
+	// 
+	FileWav_set_change_parameters_is_selected (StrFreq, StrVoie, StrBits);
 }
 // 
 // 
@@ -1270,24 +937,14 @@ void FileWav_from_popup (TYPE_SET_FROM_POPUP_FILE TypeSetFromPopup, DETAIL *deta
 	// SELECTION ou DESELECTION POUR FREQUENCES VOIE BITS 
 	
 	case FILEWAV_FREQUENCY_CELL_HERTZ :		// Frequence Cellule ou valeur d origine
-		FileWav_from_popup_set_data (NULL, StrFreq, StrVoie, StrBits);
-		break;
-	case FILEWAV_FREQUENCY_COL_HERTZ :		// Frequence Colonne ou valeur d origine
-		FileWav_from_popup_set_data (detail, StrFreq, StrVoie, StrBits);
+		FileWav_from_popup_set_data (StrFreq, StrVoie, StrBits);
 		break;
 	case FILEWAV_TRACK_CELL :			// Voie Cellule ou valeur d origine
-		FileWav_from_popup_set_data (NULL, StrFreq, StrVoie, StrBits);
-		break;
-	case FILEWAV_TRACK_COL :			// Voie Colonne ou valeur d origine
-		FileWav_from_popup_set_data (detail, StrFreq, StrVoie, StrBits);
+		FileWav_from_popup_set_data (StrFreq, StrVoie, StrBits);
 		break;
 	case FILEWAV_QUANTIFICATION_CELL :		// Bits Cellule ou valeur d origine
-		FileWav_from_popup_set_data (NULL, StrFreq, StrVoie, StrBits);
+		FileWav_from_popup_set_data (StrFreq, StrVoie, StrBits);
 		break;
-	case FILEWAV_QUANTIFICATION_COL :		// Bits Colonne ou valeur d origine
-		FileWav_from_popup_set_data (detail, StrFreq, StrVoie, StrBits);
-		break;
-	
 	}
 	
 	if (NULL != StrFreq)	{ g_free (StrFreq);	StrFreq = NULL; }
