@@ -29,17 +29,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-	// #include <libintl.h>
-	//#define _(String) gettext (String)
-	/* INTERNATIONALISATION DE DATAS DEPUIS LES STRUCTURES :
-	 *	http://chl.be/glmf/www.linuxmag-france.org/old/lm5/inter.html
-	 */
-	#define gettext_noop(x) (x) 
-#endif
-
 #include <gtk/gtk.h>
 #include <stdlib.h>
 #include <string.h>
