@@ -72,7 +72,6 @@
 #include "split.h"
 #include "alsa_play.h"
 #include "win_info.h"
-#include "popup_systray.h"
 #include "statusbar.h"
 #include "cd_curl.h"
 #include "bacon.h"
@@ -325,6 +324,27 @@ gboolean on_wind_main_key_release_event( GtkWidget *widget, GdkEventKey *kevent,
 	
 	return FALSE;
 }
+
+gboolean on_wind_main_window_state_event( GtkWidget *widget, GdkEventWindowState *event, gpointer ser_data )
+{
+	/*
+	typedef enum
+	{
+	  GDK_WINDOW_STATE_WITHDRAWN  = 1 << 0,
+	  GDK_WINDOW_STATE_ICONIFIED  = 1 << 1,
+	  GDK_WINDOW_STATE_MAXIMIZED  = 1 << 2,
+	  GDK_WINDOW_STATE_STICKY     = 1 << 3,
+	  GDK_WINDOW_STATE_FULLSCREEN = 1 << 4,
+	  GDK_WINDOW_STATE_ABOVE      = 1 << 5,
+	  GDK_WINDOW_STATE_BELOW      = 1 << 6
+	} GdkWindowState;
+	*/
+	if( GDK_WINDOW_STATE_MAXIMIZED == event->new_window_state ) {
+		gdk_window_maximize( WindMain->window );
+	}
+	return FALSE;
+}
+
 // 
 // 
 gboolean on_wind_main_delete_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
@@ -421,10 +441,6 @@ GList *AnalyseCommandLine_set_argv( gint argc, gchar *argv[], PARAMS_CMD_LINE Pa
 			else if( 0 == strcmp( argv[i], "-help" ) || 0 == strcmp( argv[i], "-h" )) {
 				OptionsCommandLine.BoolHelpMode = TRUE;
 			}
-			// BoolSystray
-			else if( 0 == strcmp( argv[i], "-systray" )) {
-				OptionsCommandLine.BoolSystray = TRUE;
-			}
 		}
 		
 		// STOP ?
@@ -475,7 +491,7 @@ void main_save( GList *p_GListFile )
 			while( list ) {
 				if (NULL != (PtrName = (gchar *)list->data)) {
 					fprintf( fp, "%s\n", PtrName );
-					g_print( "%s\n", PtrName );
+					if( TRUE == OptionsCommandLine.BoolVersionMode ) g_print( "%s\n", PtrName );
 				}
 				list = g_list_next( list );
 			}
@@ -535,7 +551,6 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 			g_print( "	-help -h	Displays this help section and exits\n" );
 			g_print( "	-version	Displays the version of the program and exits\n" );
 			g_print( "	-verbose	Activate verbose mode\n" );
-			g_print( "	-systray	Activate systray mode\n" );
 		}
 		g_print( "\n" );
 		g_unlink( XCFA_FILE_LOAD );
@@ -683,11 +698,7 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	PackageVersion = NULL;
 	
 	libutils_set_default_icone_to_win (WindMain);
-	
-	// SYSTRAY: CREATION DE L'ICONE DE STATUS + INFO-BULLE
-	if( TRUE == OptionsCommandLine.BoolSystray )
-		PopupSystray_init ();
-	
+		
 	gtk_widget_show (WindMain);
 	
 	// NOTEBOOK
