@@ -30,11 +30,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <glib.h>
 #include <gdk/gdkkeysyms.h>
@@ -237,7 +232,6 @@ void pochedir_recherche_recursive_ (gchar *Directory)
 	DIR    *dp;
 	struct  dirent *entry;
 	struct  stat statbuf;
-	gint	Dummy;
 	
 	if (NULL == (dp = opendir (Directory))) {
 		if (TRUE == libutils_test_file_exist (Directory) && libutils_get_size_file (Directory) > 100) {
@@ -247,7 +241,7 @@ void pochedir_recherche_recursive_ (gchar *Directory)
 		return;
 	}
 		
-	Dummy = chdir (Directory);
+	chdir (Directory);
 	while ((entry = readdir (dp)) != NULL) {
 		
 		if (WindScan_close_request () == TRUE) break;
@@ -286,7 +280,7 @@ void pochedir_recherche_recursive_ (gchar *Directory)
 			}
 		}
 	}
-	Dummy = chdir ("..");
+	chdir ("..");
 	closedir (dp);
 }
 // 
