@@ -473,36 +473,9 @@ void on_CellTrackOriginal_activate( GtkMenuItem *menuitem, gpointer user_data )
 	DETAIL *detail = ( DETAIL *)user_data;
 	FileWav_from_popup( FILEWAV_TRACK_CELL, detail, -2, -1, -2 );
 }
-void on_ColTrack1_activate( GtkMenuItem *menuitem, gpointer user_data )
-{
-	DETAIL *detail = ( DETAIL *)user_data;
-	FileWav_from_popup( FILEWAV_TRACK_COL, detail, -2, 1, -2 );
-}
-void on_ColTrack2_activate( GtkMenuItem *menuitem, gpointer user_data )
-{
-	DETAIL *detail = ( DETAIL *)user_data;
-	FileWav_from_popup( FILEWAV_TRACK_COL, detail, -2, 2, -2 );
-}
-void on_ColTrack4_activate( GtkMenuItem *menuitem, gpointer user_data )
-{
-	DETAIL *detail = ( DETAIL *)user_data;
-	FileWav_from_popup( FILEWAV_TRACK_COL, detail, -2, 4, -2 );
-}
-void on_ColTrack6_activate( GtkMenuItem *menuitem, gpointer user_data )
-{
-	DETAIL *detail = ( DETAIL *)user_data;
-	FileWav_from_popup( FILEWAV_TRACK_COL, detail, -2, 6, -2 );
-}
-void on_ColTrackOriginal_activate( GtkMenuItem *menuitem, gpointer user_data )
-{
-	DETAIL *detail = ( DETAIL *)user_data;
-	FileWav_from_popup( FILEWAV_TRACK_COL, detail, -2, -1, -2 );
-}
 void popup_file_wav_piste( DETAIL *detail)
 {
 	GtkWidget *Menu;
-	GtkWidget *CellTrack;
-	GtkWidget *CellSubMenu;
 	GtkWidget *CellTrack1;
 	GtkWidget *CellTrack2;
 	GtkWidget *CellTrack4;
@@ -510,82 +483,35 @@ void popup_file_wav_piste( DETAIL *detail)
 	GtkWidget *CellSeparate;
 	GtkWidget *CellTrackOriginal;
 
-	GtkWidget *ColTrack;
-	GtkWidget *ColSubMenu;
-	GtkWidget *ColTrack1;
-	GtkWidget *ColTrack2;
-	GtkWidget *ColTrack4;
-	GtkWidget *ColTrack6;
-	GtkWidget *ColSeparate;
-	GtkWidget *ColTrackOriginal;
 	
 	Menu = gtk_menu_new(  );
-	gtk_widget_set_extension_events( Menu, GDK_EXTENSION_EVENTS_ALL );
-	CellTrack = gtk_menu_item_new_with_mnemonic( _("Cellule") );
-	gtk_widget_show( CellTrack );
-	gtk_container_add( GTK_CONTAINER( Menu), CellTrack ); 
 	
-	CellSubMenu = gtk_menu_new(  );
-	gtk_menu_item_set_submenu( GTK_MENU_ITEM( CellTrack), CellSubMenu );
-		
 	CellTrack1 = gtk_menu_item_new_with_mnemonic( _("1  piste") );
 	gtk_widget_show( CellTrack1 );
-	gtk_container_add( GTK_CONTAINER( CellSubMenu), CellTrack1  );
+	gtk_container_add( GTK_CONTAINER( Menu), CellTrack1  );
 	CellTrack2 = gtk_menu_item_new_with_mnemonic( _("2  pistes") );
 	gtk_widget_show( CellTrack2 );
-	gtk_container_add( GTK_CONTAINER( CellSubMenu), CellTrack2  );
+	gtk_container_add( GTK_CONTAINER( Menu), CellTrack2  );
 	CellTrack4 = gtk_menu_item_new_with_mnemonic( _("4  pistes") );
 	gtk_widget_show( CellTrack4 );
-	gtk_container_add( GTK_CONTAINER( CellSubMenu), CellTrack4  );
+	gtk_container_add( GTK_CONTAINER( Menu), CellTrack4  );
 	CellTrack6 = gtk_menu_item_new_with_mnemonic( _("6  pistes") );
 	gtk_widget_show( CellTrack6 );
-	gtk_container_add( GTK_CONTAINER( CellSubMenu), CellTrack6  );
+	gtk_container_add( GTK_CONTAINER( Menu), CellTrack6  );
 	CellSeparate = gtk_separator_menu_item_new(  );
 	gtk_widget_show( CellSeparate );
-	gtk_container_add( GTK_CONTAINER( CellSubMenu), CellSeparate );
+	gtk_container_add( GTK_CONTAINER( Menu), CellSeparate );
 	CellTrackOriginal = gtk_menu_item_new_with_mnemonic( _("Valeur d'origine") );
 	gtk_widget_show( CellTrackOriginal );
-	gtk_container_add( GTK_CONTAINER( CellSubMenu), CellTrackOriginal  );
-	
-	ColTrack = gtk_menu_item_new_with_mnemonic( _("Colonne") );
-	gtk_widget_show( ColTrack );
-	gtk_container_add( GTK_CONTAINER( Menu), ColTrack ); 
-	
-	ColSubMenu = gtk_menu_new(  );
-	gtk_menu_item_set_submenu( GTK_MENU_ITEM( ColTrack), ColSubMenu );
-	
-	ColTrack1 = gtk_menu_item_new_with_mnemonic( _("1  piste") );
-	gtk_widget_show( ColTrack1 );
-	gtk_container_add( GTK_CONTAINER( ColSubMenu), ColTrack1  );
-	ColTrack2 = gtk_menu_item_new_with_mnemonic( _("2  pistes") );
-	gtk_widget_show( ColTrack2 );
-	gtk_container_add( GTK_CONTAINER( ColSubMenu), ColTrack2  );
-	ColTrack4 = gtk_menu_item_new_with_mnemonic( _("4  pistes") );
-	gtk_widget_show( ColTrack4 );
-	gtk_container_add( GTK_CONTAINER( ColSubMenu), ColTrack4  );
-	ColTrack6 = gtk_menu_item_new_with_mnemonic( _("6  pistes") );
-	gtk_widget_show( ColTrack6 );
-	gtk_container_add( GTK_CONTAINER( ColSubMenu), ColTrack6  );
-	ColSeparate = gtk_separator_menu_item_new(  );
-	gtk_widget_show( ColSeparate );
-	gtk_container_add( GTK_CONTAINER( ColSubMenu), ColSeparate );
-	ColTrackOriginal = gtk_menu_item_new_with_mnemonic( _("Valeur d'origine") );
-	gtk_widget_show( ColTrackOriginal );
-	gtk_container_add( GTK_CONTAINER( ColSubMenu), ColTrackOriginal  );
+	gtk_container_add( GTK_CONTAINER( Menu), CellTrackOriginal  );
 	
 	g_signal_connect(( gpointer) CellTrack1,        "activate", G_CALLBACK( on_CellTrack1_activate),        detail  );
 	g_signal_connect(( gpointer) CellTrack2,        "activate", G_CALLBACK( on_CellTrack2_activate),        detail  );
 	g_signal_connect(( gpointer) CellTrack4,        "activate", G_CALLBACK( on_CellTrack4_activate),        detail  );
 	g_signal_connect(( gpointer) CellTrack6,        "activate", G_CALLBACK( on_CellTrack6_activate),        detail  );
 	g_signal_connect(( gpointer) CellTrackOriginal, "activate", G_CALLBACK( on_CellTrackOriginal_activate), detail  );
-	g_signal_connect(( gpointer) ColTrack1,         "activate", G_CALLBACK( on_ColTrack1_activate),         detail  );
-	g_signal_connect(( gpointer) ColTrack2,         "activate", G_CALLBACK( on_ColTrack2_activate),         detail  );
-	g_signal_connect(( gpointer) ColTrack4,         "activate", G_CALLBACK( on_ColTrack4_activate),         detail  );
-	g_signal_connect(( gpointer) ColTrack6,         "activate", G_CALLBACK( on_ColTrack6_activate),         detail  );
-	g_signal_connect(( gpointer) ColTrackOriginal,  "activate", G_CALLBACK( on_ColTrackOriginal_activate),  detail  );
 	
 	GLADE_HOOKUP_OBJECT_NO_REF( Menu, Menu,       "Menu" );
-	GLADE_HOOKUP_OBJECT( Menu, CellSubMenu,       "CellSubMenu" );
 	GLADE_HOOKUP_OBJECT( Menu, CellTrack1,        "CellTrack1" );
 	GLADE_HOOKUP_OBJECT( Menu, CellTrack2,        "CellTrack2" );
 	GLADE_HOOKUP_OBJECT( Menu, CellTrack4,        "CellTrack4" );
@@ -593,14 +519,6 @@ void popup_file_wav_piste( DETAIL *detail)
 	GLADE_HOOKUP_OBJECT( Menu, CellSeparate,      "CellSeparate" );
 	GLADE_HOOKUP_OBJECT( Menu, CellTrackOriginal, "CellTrackOriginal" );
 
-	GLADE_HOOKUP_OBJECT( Menu, ColSubMenu,        "ColSubMenu" );
-	GLADE_HOOKUP_OBJECT( Menu, ColTrack1,         "ColTrack1" );
-	GLADE_HOOKUP_OBJECT( Menu, ColTrack2,         "ColTrack2" );
-	GLADE_HOOKUP_OBJECT( Menu, ColTrack4,         "ColTrack4" );
-	GLADE_HOOKUP_OBJECT( Menu, ColTrack6,         "ColTrack6" );
-	GLADE_HOOKUP_OBJECT( Menu, ColSeparate,       "ColSeparate" );
-	GLADE_HOOKUP_OBJECT( Menu, ColTrackOriginal,  "ColTrackOriginal" );
-	
 	gtk_menu_popup( GTK_MENU( Menu), NULL, NULL, NULL, NULL, 3, 0 );
 }
 // 
@@ -653,56 +571,9 @@ void on_CellHertzOriginal_activate( GtkMenuItem *menuitem, gpointer user_data )
 	DETAIL *detail = ( DETAIL *)user_data;
 	FileWav_from_popup( FILEWAV_FREQUENCY_CELL_HERTZ, detail, -1, -2, -2 );
 }
-void on_ColHertz8000_activate( GtkMenuItem *menuitem, gpointer user_data )
-{
-	DETAIL *detail = ( DETAIL *)user_data;
-	FileWav_from_popup( FILEWAV_FREQUENCY_COL_HERTZ, detail, 8000, -2, -2 );
-}
-void on_ColHertz22000_activate( GtkMenuItem *menuitem, gpointer user_data )
-{
-	DETAIL *detail = ( DETAIL *)user_data;
-	FileWav_from_popup( FILEWAV_FREQUENCY_COL_HERTZ, detail, 22000, -2, -2 );
-}
-void on_ColHertz32000_activate( GtkMenuItem *menuitem, gpointer user_data )
-{
-	DETAIL *detail = ( DETAIL *)user_data;
-	FileWav_from_popup( FILEWAV_FREQUENCY_COL_HERTZ, detail, 32000, -2, -2 );
-}
-void on_ColHertz44056_activate( GtkMenuItem *menuitem, gpointer user_data )
-{
-	DETAIL *detail = ( DETAIL *)user_data;
-	FileWav_from_popup( FILEWAV_FREQUENCY_COL_HERTZ, detail, 44056, -2, -2 );
-}
-void on_ColHertz44100_activate( GtkMenuItem *menuitem, gpointer user_data )
-{
-	DETAIL *detail = ( DETAIL *)user_data;
-	FileWav_from_popup( FILEWAV_FREQUENCY_COL_HERTZ, detail, 44100, -2, -2 );
-}
-void on_ColHertz48000_activate( GtkMenuItem *menuitem, gpointer user_data )
-{
-	DETAIL *detail = ( DETAIL *)user_data;
-	FileWav_from_popup( FILEWAV_FREQUENCY_COL_HERTZ, detail, 48000, -2, -2 );
-}
-void on_ColHertz88200_activate( GtkMenuItem *menuitem, gpointer user_data )
-{
-	DETAIL *detail = ( DETAIL *)user_data;
-	FileWav_from_popup( FILEWAV_FREQUENCY_COL_HERTZ, detail, 88200, -2, -2 );
-}
-void on_ColHertz96000_activate( GtkMenuItem *menuitem, gpointer user_data )
-{
-	DETAIL *detail = ( DETAIL *)user_data;
-	FileWav_from_popup( FILEWAV_FREQUENCY_COL_HERTZ, detail, 96000, -2, -2 );
-}
-void on_ColHertzOriginal_activate( GtkMenuItem *menuitem, gpointer user_data )
-{
-	DETAIL *detail = ( DETAIL *)user_data;
-	FileWav_from_popup( FILEWAV_FREQUENCY_COL_HERTZ, detail, -1, -2, -2 );
-}
 void popup_file_wav_frequence( DETAIL *detail)
 {
 	GtkWidget *Menu;
-	GtkWidget *CellHertz;
-	GtkWidget *CellSubMenu;
 	GtkWidget *CellHertz8000;
 	GtkWidget *CellHertz22000;
 	GtkWidget *CellHertz32000;
@@ -713,98 +584,42 @@ void popup_file_wav_frequence( DETAIL *detail)
 	GtkWidget *CellHertz96000;
 	GtkWidget *CellSeparate;
 	GtkWidget *CellHertzOriginal;
-	
-	GtkWidget *ColHertz;
-	GtkWidget *ColSubMenu;
-	GtkWidget *ColHertz8000;
-	GtkWidget *ColHertz22000;
-	GtkWidget *ColHertz32000;
-	GtkWidget *ColHertz44056;
-	GtkWidget *ColHertz44100;
-	GtkWidget *ColHertz48000;
-	GtkWidget *ColHertz88200;
-	GtkWidget *ColHertz96000;
-	GtkWidget *ColSeparate;
-	GtkWidget *ColHertzOriginal;
-	
+		
 	Menu = gtk_menu_new(  );
 	gtk_widget_set_extension_events( Menu, GDK_EXTENSION_EVENTS_ALL );
-	CellHertz = gtk_menu_item_new_with_mnemonic( _("Cellule") );
-	gtk_widget_show( CellHertz );
-	gtk_container_add( GTK_CONTAINER( Menu), CellHertz ); 
-	
-	CellSubMenu = gtk_menu_new(  );
-	gtk_menu_item_set_submenu( GTK_MENU_ITEM( CellHertz), CellSubMenu );
 		
+
 	CellHertz8000 = gtk_menu_item_new_with_mnemonic( _(" 8000  Hertz") );
 	gtk_widget_show( CellHertz8000 );
-	gtk_container_add( GTK_CONTAINER( CellSubMenu), CellHertz8000  );
+	gtk_container_add( GTK_CONTAINER( Menu), CellHertz8000  );
 	CellHertz22000 = gtk_menu_item_new_with_mnemonic( _("22000  Hertz") );
 	gtk_widget_show( CellHertz22000 );
-	gtk_container_add( GTK_CONTAINER( CellSubMenu), CellHertz22000  );
+	gtk_container_add( GTK_CONTAINER( Menu), CellHertz22000  );
 	CellHertz32000 = gtk_menu_item_new_with_mnemonic( _("32000  Hertz") );
 	gtk_widget_show( CellHertz32000 );
-	gtk_container_add( GTK_CONTAINER( CellSubMenu), CellHertz32000  );
+	gtk_container_add( GTK_CONTAINER( Menu), CellHertz32000  );
 	CellHertz44056 = gtk_menu_item_new_with_mnemonic( _("44056  Hertz") );
 	gtk_widget_show( CellHertz44056 );
-	gtk_container_add( GTK_CONTAINER( CellSubMenu), CellHertz44056  );
+	gtk_container_add( GTK_CONTAINER( Menu), CellHertz44056  );
 	CellHertz44100 = gtk_menu_item_new_with_mnemonic( _("44100  Hertz") );
 	gtk_widget_show( CellHertz44100 );
-	gtk_container_add( GTK_CONTAINER( CellSubMenu), CellHertz44100  );
+	gtk_container_add( GTK_CONTAINER( Menu), CellHertz44100  );
 	CellHertz48000 = gtk_menu_item_new_with_mnemonic( _("48000  Hertz") );
 	gtk_widget_show( CellHertz48000 );
-	gtk_container_add( GTK_CONTAINER( CellSubMenu), CellHertz48000  );
+	gtk_container_add( GTK_CONTAINER( Menu), CellHertz48000  );
 	CellHertz88200 = gtk_menu_item_new_with_mnemonic( _("88200  Hertz") );
 	gtk_widget_show( CellHertz88200 );
-	gtk_container_add( GTK_CONTAINER( CellSubMenu), CellHertz88200  );
+	gtk_container_add( GTK_CONTAINER( Menu), CellHertz88200  );
 	CellHertz96000 = gtk_menu_item_new_with_mnemonic( _("96000  Hertz") );
 	gtk_widget_show( CellHertz96000 );
-	gtk_container_add( GTK_CONTAINER( CellSubMenu), CellHertz96000  );
+	gtk_container_add( GTK_CONTAINER( Menu), CellHertz96000  );
 	CellSeparate = gtk_separator_menu_item_new(  );
 	gtk_widget_show( CellSeparate );
-	gtk_container_add( GTK_CONTAINER( CellSubMenu), CellSeparate );
+	gtk_container_add( GTK_CONTAINER( Menu), CellSeparate );
 	CellHertzOriginal = gtk_menu_item_new_with_mnemonic( _("Valeur d'origine") );
 	gtk_widget_show( CellHertzOriginal );
-	gtk_container_add( GTK_CONTAINER( CellSubMenu), CellHertzOriginal  );
+	gtk_container_add( GTK_CONTAINER( Menu), CellHertzOriginal  );
 	
-	ColHertz = gtk_menu_item_new_with_mnemonic( _("Colonne") );
-	gtk_widget_show( ColHertz );
-	gtk_container_add( GTK_CONTAINER( Menu), ColHertz ); 
-	
-	ColSubMenu = gtk_menu_new(  );
-	gtk_menu_item_set_submenu( GTK_MENU_ITEM( ColHertz), ColSubMenu );
-	
-	ColHertz8000 = gtk_menu_item_new_with_mnemonic( _(" 8000  Hertz") );
-	gtk_widget_show( ColHertz8000 );
-	gtk_container_add( GTK_CONTAINER( ColSubMenu), ColHertz8000  );
-	ColHertz22000 = gtk_menu_item_new_with_mnemonic( _("22000  Hertz") );
-	gtk_widget_show( ColHertz22000 );
-	gtk_container_add( GTK_CONTAINER( ColSubMenu), ColHertz22000  );
-	ColHertz32000 = gtk_menu_item_new_with_mnemonic( _("32000  Hertz") );
-	gtk_widget_show( ColHertz32000 );
-	gtk_container_add( GTK_CONTAINER( ColSubMenu), ColHertz32000  );
-	ColHertz44056 = gtk_menu_item_new_with_mnemonic( _("44056  Hertz") );
-	gtk_widget_show( ColHertz44056 );
-	gtk_container_add( GTK_CONTAINER( ColSubMenu), ColHertz44056  );
-	ColHertz44100 = gtk_menu_item_new_with_mnemonic( _("44100  Hertz") );
-	gtk_widget_show( ColHertz44100 );
-	gtk_container_add( GTK_CONTAINER( ColSubMenu), ColHertz44100  );
-	ColHertz48000 = gtk_menu_item_new_with_mnemonic( _("48000  Hertz") );
-	gtk_widget_show( ColHertz48000 );
-	gtk_container_add( GTK_CONTAINER( ColSubMenu), ColHertz48000  );
-	ColHertz88200 = gtk_menu_item_new_with_mnemonic( _("88200  Hertz") );
-	gtk_widget_show( ColHertz88200 );
-	gtk_container_add( GTK_CONTAINER( ColSubMenu), ColHertz88200  );
-	ColHertz96000 = gtk_menu_item_new_with_mnemonic( _("96000  Hertz") );
-	gtk_widget_show( ColHertz96000 );
-	gtk_container_add( GTK_CONTAINER( ColSubMenu), ColHertz96000  );
-	ColSeparate = gtk_separator_menu_item_new(  );
-	gtk_widget_show( ColSeparate );
-	gtk_container_add( GTK_CONTAINER( ColSubMenu), ColSeparate );
-	ColHertzOriginal = gtk_menu_item_new_with_mnemonic( _("Valeur d'origine") );
-	gtk_widget_show( ColHertzOriginal );
-	gtk_container_add( GTK_CONTAINER( ColSubMenu), ColHertzOriginal  );
-		
 	g_signal_connect(( gpointer) CellHertz8000,     "activate", G_CALLBACK( on_CellHertz8000_activate),     detail  );
 	g_signal_connect(( gpointer) CellHertz22000,    "activate", G_CALLBACK( on_CellHertz22000_activate),    detail  );
 	g_signal_connect(( gpointer) CellHertz32000,    "activate", G_CALLBACK( on_CellHertz32000_activate),    detail  );
@@ -814,20 +629,9 @@ void popup_file_wav_frequence( DETAIL *detail)
 	g_signal_connect(( gpointer) CellHertz88200,    "activate", G_CALLBACK( on_CellHertz88200_activate),    detail  );
 	g_signal_connect(( gpointer) CellHertz96000,    "activate", G_CALLBACK( on_CellHertz96000_activate),    detail  );
 	g_signal_connect(( gpointer) CellHertzOriginal, "activate", G_CALLBACK( on_CellHertzOriginal_activate), detail  );
-	
-	g_signal_connect(( gpointer) ColHertz8000,      "activate", G_CALLBACK( on_ColHertz8000_activate),      detail  );
-	g_signal_connect(( gpointer) ColHertz22000,     "activate", G_CALLBACK( on_ColHertz22000_activate),     detail  );
-	g_signal_connect(( gpointer) ColHertz32000,     "activate", G_CALLBACK( on_ColHertz32000_activate),     detail  );
-	g_signal_connect(( gpointer) ColHertz44056,     "activate", G_CALLBACK( on_ColHertz44056_activate),     detail  );
-	g_signal_connect(( gpointer) ColHertz44100,     "activate", G_CALLBACK( on_ColHertz44100_activate),     detail  );
-	g_signal_connect(( gpointer) ColHertz48000,     "activate", G_CALLBACK( on_ColHertz48000_activate),     detail  );
-	g_signal_connect(( gpointer) ColHertz88200,     "activate", G_CALLBACK( on_ColHertz88200_activate),     detail  );
-	g_signal_connect(( gpointer) ColHertz96000,     "activate", G_CALLBACK( on_ColHertz96000_activate),     detail  );
-	g_signal_connect(( gpointer) ColHertzOriginal,  "activate", G_CALLBACK( on_ColHertzOriginal_activate),  detail  );
 
 	GLADE_HOOKUP_OBJECT_NO_REF( Menu, Menu,  "Menu" );
-	GLADE_HOOKUP_OBJECT( Menu, CellHertz,         "CellHertz" );
-	GLADE_HOOKUP_OBJECT( Menu, CellSubMenu,       "CellSubMenu" );
+	GLADE_HOOKUP_OBJECT( Menu, Menu,       		"Menu" );
 	GLADE_HOOKUP_OBJECT( Menu, CellHertz8000,     "CellHertz8000" );
 	GLADE_HOOKUP_OBJECT( Menu, CellHertz22000,    "CellHertz22000" );
 	GLADE_HOOKUP_OBJECT( Menu, CellHertz32000,    "CellHertz32000" );
@@ -838,19 +642,6 @@ void popup_file_wav_frequence( DETAIL *detail)
 	GLADE_HOOKUP_OBJECT( Menu, CellHertz96000,    "CellHertz96000" );
 	GLADE_HOOKUP_OBJECT( Menu, CellSeparate,      "CellSeparate" );
 	GLADE_HOOKUP_OBJECT( Menu, CellHertzOriginal, "CellHertzOriginal" );
-	
-	GLADE_HOOKUP_OBJECT( Menu, ColHertz,          "ColHertz" );
-	GLADE_HOOKUP_OBJECT( Menu, ColSubMenu,        "ColSubMenu" );
-	GLADE_HOOKUP_OBJECT( Menu, ColHertz8000,      "ColHertz8000" );
-	GLADE_HOOKUP_OBJECT( Menu, ColHertz22000,     "ColHertz22000" );
-	GLADE_HOOKUP_OBJECT( Menu, ColHertz32000,     "ColHertz32000" );
-	GLADE_HOOKUP_OBJECT( Menu, ColHertz44056,     "ColHertz44056" );
-	GLADE_HOOKUP_OBJECT( Menu, ColHertz44100,     "ColHertz44100" );
-	GLADE_HOOKUP_OBJECT( Menu, ColHertz48000,     "ColHertz48000" );
-	GLADE_HOOKUP_OBJECT( Menu, ColHertz88200,     "ColHertz88200" );
-	GLADE_HOOKUP_OBJECT( Menu, ColHertz96000,     "ColHertz96000" );
-	GLADE_HOOKUP_OBJECT( Menu, ColSeparate,       "ColSeparate" );
-	GLADE_HOOKUP_OBJECT( Menu, ColHertzOriginal,  "ColHertzOriginal" );
 
 	gtk_menu_popup( GTK_MENU( Menu), NULL, NULL, NULL, NULL, 3, 0 );
 }
@@ -889,42 +680,9 @@ void on_CellOriginal_activate( GtkMenuItem *menuitem, gpointer user_data )
 	DETAIL *detail = ( DETAIL *)user_data;
 	FileWav_from_popup( FILEWAV_QUANTIFICATION_CELL, detail, -2, -2, -1 );
 }
-	
-void on_ColWav8_activate( GtkMenuItem *menuitem, gpointer user_data )
-{
-	DETAIL *detail = ( DETAIL *)user_data;
-	FileWav_from_popup( FILEWAV_QUANTIFICATION_COL, detail, -2, -2, 8 );
-}
-void on_ColWav16_activate( GtkMenuItem *menuitem, gpointer user_data )
-{
-	DETAIL *detail = ( DETAIL *)user_data;
-	FileWav_from_popup( FILEWAV_QUANTIFICATION_COL, detail, -2, -2, 16 );
-}
-void on_ColWav24_activate( GtkMenuItem *menuitem, gpointer user_data )
-{
-	DETAIL *detail = ( DETAIL *)user_data;
-	FileWav_from_popup( FILEWAV_QUANTIFICATION_COL, detail, -2, -2, 24 );
-}
-void on_ColWav32_activate( GtkMenuItem *menuitem, gpointer user_data )
-{
-	DETAIL *detail = ( DETAIL *)user_data;
-	FileWav_from_popup( FILEWAV_QUANTIFICATION_COL, detail, -2, -2, 32 );
-}
-void on_ColWav64_activate( GtkMenuItem *menuitem, gpointer user_data )
-{
-	DETAIL *detail = ( DETAIL *)user_data;
-	FileWav_from_popup( FILEWAV_QUANTIFICATION_COL, detail, -2, -2, 64 );
-}
-void on_ColOriginal_activate( GtkMenuItem *menuitem, gpointer user_data )
-{
-	DETAIL *detail = ( DETAIL *)user_data;
-	FileWav_from_popup( FILEWAV_QUANTIFICATION_COL, detail, -2, -2, -1 );
-}
 void popup_file_wav_quantification( DETAIL *detail)
 {
 	GtkWidget *Menu;
-	GtkWidget *CellWav;
-	GtkWidget *CellSubMenu;
 	GtkWidget *CellWav8;
 	GtkWidget *CellWav16;
 	GtkWidget *CellWav24;
@@ -932,77 +690,32 @@ void popup_file_wav_quantification( DETAIL *detail)
 	GtkWidget *CellWav64;
 	GtkWidget *CellSeparate;
 	GtkWidget *CellOriginal;
-
-	GtkWidget *ColWav;
-	GtkWidget *ColSubMenu;
-	GtkWidget *ColWav8;
-	GtkWidget *ColWav16;
-	GtkWidget *ColWav24;
-	GtkWidget *ColWav32;
-	GtkWidget *ColWav64;
-	GtkWidget *ColSeparate;
-	GtkWidget *ColOriginal;
 	
 	Menu = gtk_menu_new(  );
-	gtk_widget_set_extension_events( Menu, GDK_EXTENSION_EVENTS_ALL );
-	CellWav = gtk_menu_item_new_with_mnemonic( _("Cellule") );
-	gtk_widget_show( CellWav );
-	gtk_container_add( GTK_CONTAINER( Menu), CellWav ); 
 	
-	CellSubMenu = gtk_menu_new(  );
-	gtk_menu_item_set_submenu( GTK_MENU_ITEM( CellWav), CellSubMenu );
+	gtk_widget_set_extension_events( Menu, GDK_EXTENSION_EVENTS_ALL );
 		
 	CellWav8 = gtk_menu_item_new_with_mnemonic( _(" 8  bits") );
 	gtk_widget_show( CellWav8 );
-	gtk_container_add( GTK_CONTAINER( CellSubMenu), CellWav8  );
+	gtk_container_add( GTK_CONTAINER( Menu), CellWav8  );
 	CellWav16 = gtk_menu_item_new_with_mnemonic( _("16  bits") );
 	gtk_widget_show( CellWav16 );
-	gtk_container_add( GTK_CONTAINER( CellSubMenu), CellWav16  );
+	gtk_container_add( GTK_CONTAINER( Menu), CellWav16  );
 	CellWav24 = gtk_menu_item_new_with_mnemonic( _("24  bits") );
 	gtk_widget_show( CellWav24 );
-	gtk_container_add( GTK_CONTAINER( CellSubMenu), CellWav24  );
+	gtk_container_add( GTK_CONTAINER( Menu), CellWav24  );
 	CellWav32 = gtk_menu_item_new_with_mnemonic( _("32  bits") );
 	gtk_widget_show( CellWav32 );
-	gtk_container_add( GTK_CONTAINER( CellSubMenu), CellWav32  );
+	gtk_container_add( GTK_CONTAINER( Menu), CellWav32  );
 	CellWav64 = gtk_menu_item_new_with_mnemonic( _("64  bits") );
 	gtk_widget_show( CellWav64 );
-	gtk_container_add( GTK_CONTAINER( CellSubMenu), CellWav64  );
+	gtk_container_add( GTK_CONTAINER( Menu), CellWav64  );
 	CellSeparate = gtk_separator_menu_item_new(  );
 	gtk_widget_show( CellSeparate );
-	gtk_container_add( GTK_CONTAINER( CellSubMenu), CellSeparate );
+	gtk_container_add( GTK_CONTAINER( Menu), CellSeparate );
 	CellOriginal = gtk_menu_item_new_with_mnemonic( _("Valeur d'origine") );
 	gtk_widget_show( CellOriginal );
-	gtk_container_add( GTK_CONTAINER( CellSubMenu), CellOriginal  );
-	
-	ColWav = gtk_menu_item_new_with_mnemonic( _("Colonne") );
-	gtk_widget_show( ColWav );
-	gtk_container_add( GTK_CONTAINER( Menu), ColWav ); 
-	
-	ColSubMenu = gtk_menu_new(  );
-	gtk_menu_item_set_submenu( GTK_MENU_ITEM( ColWav), ColSubMenu );
-		
-	ColWav8 = gtk_menu_item_new_with_mnemonic( _(" 8  bits") );
-	gtk_widget_show( ColWav8 );
-	gtk_container_add( GTK_CONTAINER( ColSubMenu), ColWav8  );
-	
-	ColWav16 = gtk_menu_item_new_with_mnemonic( _("16  bits") );
-	gtk_widget_show( ColWav16 );
-	gtk_container_add( GTK_CONTAINER( ColSubMenu), ColWav16  );
-	ColWav24 = gtk_menu_item_new_with_mnemonic( _("24  bits") );
-	gtk_widget_show( ColWav24 );
-	gtk_container_add( GTK_CONTAINER( ColSubMenu), ColWav24  );
-	ColWav32 = gtk_menu_item_new_with_mnemonic( _("32  bits") );
-	gtk_widget_show( ColWav32 );
-	gtk_container_add( GTK_CONTAINER( ColSubMenu), ColWav32  );
-	ColWav64 = gtk_menu_item_new_with_mnemonic( _("64  bits") );
-	gtk_widget_show( ColWav64 );
-	gtk_container_add( GTK_CONTAINER( ColSubMenu), ColWav64  );
-	ColSeparate = gtk_separator_menu_item_new(  );
-	gtk_widget_show( ColSeparate );
-	gtk_container_add( GTK_CONTAINER( ColSubMenu), ColSeparate );
-	ColOriginal = gtk_menu_item_new_with_mnemonic( _("Valeur d'origine") );
-	gtk_widget_show( ColOriginal );
-	gtk_container_add( GTK_CONTAINER( ColSubMenu), ColOriginal  );
+	gtk_container_add( GTK_CONTAINER( Menu), CellOriginal  );
 	
 	g_signal_connect(( gpointer) CellWav8,     "activate", G_CALLBACK( on_CellWav8_activate),     detail  );
 	g_signal_connect(( gpointer) CellWav16,    "activate", G_CALLBACK( on_CellWav16_activate),    detail  );
@@ -1011,15 +724,7 @@ void popup_file_wav_quantification( DETAIL *detail)
 	g_signal_connect(( gpointer) CellWav64,    "activate", G_CALLBACK( on_CellWav64_activate),    detail  );
 	g_signal_connect(( gpointer) CellOriginal, "activate", G_CALLBACK( on_CellOriginal_activate), detail  );
 	
-	g_signal_connect(( gpointer) ColWav8,      "activate", G_CALLBACK( on_ColWav8_activate),      detail  );
-	g_signal_connect(( gpointer) ColWav16,     "activate", G_CALLBACK( on_ColWav16_activate),     detail  );
-	g_signal_connect(( gpointer) ColWav24,     "activate", G_CALLBACK( on_ColWav24_activate),     detail  );
-	g_signal_connect(( gpointer) ColWav32,     "activate", G_CALLBACK( on_ColWav32_activate),     detail  );
-	g_signal_connect(( gpointer) ColWav64,     "activate", G_CALLBACK( on_ColWav64_activate),     detail  );
-	g_signal_connect(( gpointer) ColOriginal,  "activate", G_CALLBACK( on_ColOriginal_activate),  detail  );
-
 	GLADE_HOOKUP_OBJECT_NO_REF( Menu, Menu,  "Menu" );
-	GLADE_HOOKUP_OBJECT( Menu, CellWav8,     "CellSubMenu" );
 	GLADE_HOOKUP_OBJECT( Menu, CellWav8,     "CellWav8" );
 	GLADE_HOOKUP_OBJECT( Menu, CellWav16,    "CellWav16" );
 	GLADE_HOOKUP_OBJECT( Menu, CellWav24,    "CellWav24" );
@@ -1028,15 +733,6 @@ void popup_file_wav_quantification( DETAIL *detail)
 	GLADE_HOOKUP_OBJECT( Menu, CellWav64,    "CellSeparate" );
 	GLADE_HOOKUP_OBJECT( Menu, CellOriginal, "CellOriginal" );
 	
-	GLADE_HOOKUP_OBJECT( Menu, ColWav8,      "ColSubMenu" );
-	GLADE_HOOKUP_OBJECT( Menu, ColWav8,      "ColWav8" );
-	GLADE_HOOKUP_OBJECT( Menu, ColWav16,     "ColWav16" );
-	GLADE_HOOKUP_OBJECT( Menu, ColWav24,     "ColWav24" );
-	GLADE_HOOKUP_OBJECT( Menu, ColWav32,     "ColWav32" );
-	GLADE_HOOKUP_OBJECT( Menu, ColWav64,     "ColWav64" );
-	GLADE_HOOKUP_OBJECT( Menu, ColWav64,     "ColSeparate" );
-	GLADE_HOOKUP_OBJECT( Menu, ColOriginal,  "ColOriginal" );
-	
 	gtk_menu_popup( GTK_MENU( Menu), NULL, NULL, NULL, NULL, 3, 0 );
 }
 // 
@@ -1350,27 +1046,29 @@ gchar *VarOptionsFileMp3[] = {
 void on_type_file_mp3_activate( GtkMenuItem *menuitem, gpointer user_data )
 {
 	gint	Choice = GPOINTER_TO_INT(user_data);
+	gint	Debit  = Detail_VarOptionsFileOggMp3->Mp3_Debit;
+	gint	Mode   = Detail_VarOptionsFileOggMp3->Mp3_Mode;
 	
 	if( -1 == Choice ) {
 		// g_print( "REMOVE\n");
-		Detail_VarOptionsFileOggMp3->Mp3_Debit = -1;	// SET DEBIT
-		Detail_VarOptionsFileOggMp3->Mp3_Mode  = -1;	// SET MODE
-		FileMp3Ogg_update_newbitrate( FILE_IS_MP3 );
+		Debit = Detail_VarOptionsFileOggMp3->Mp3_Debit = -1;	// SET DEBIT
+		Mode  = Detail_VarOptionsFileOggMp3->Mp3_Mode  = -1;	// SET MODE
+		FileMp3Ogg_update_newbitrate( FILE_IS_MP3, Debit, Mode, -1 );
 		return;
 	}
 	
 	// MP3: DEBIT MODE
 	if( Choice <= 59 )
-		Detail_VarOptionsFileOggMp3->Mp3_Debit = Choice;	// SET DEBIT
-	else	Detail_VarOptionsFileOggMp3->Mp3_Mode  = Choice;	// SET MODE
+		Debit = Detail_VarOptionsFileOggMp3->Mp3_Debit = Choice;	// SET DEBIT
+	else	Mode  = Detail_VarOptionsFileOggMp3->Mp3_Mode  = Choice;	// SET MODE
 	
 	// SELECTIONS DES DEUX OPTIONS OBLIGATOIRE
-	if( -1 == Detail_VarOptionsFileOggMp3->Mp3_Debit )	Detail_VarOptionsFileOggMp3->Mp3_Debit = 0;
-	if( -1 == Detail_VarOptionsFileOggMp3->Mp3_Mode )	Detail_VarOptionsFileOggMp3->Mp3_Mode  = 60;
+	if( -1 == Detail_VarOptionsFileOggMp3->Mp3_Debit )	Debit = Detail_VarOptionsFileOggMp3->Mp3_Debit = 0;
+	if( -1 == Detail_VarOptionsFileOggMp3->Mp3_Mode )	Mode  = Detail_VarOptionsFileOggMp3->Mp3_Mode  = 60;
 	
 	Detail_VarOptionsFileOggMp3->BoolChanged = ( -1 != Detail_VarOptionsFileOggMp3->Mp3_Debit || -1 != Detail_VarOptionsFileOggMp3->Mp3_Mode );
 		
-	FileMp3Ogg_update_newbitrate( FILE_IS_MP3 );
+	FileMp3Ogg_update_newbitrate( FILE_IS_MP3, Debit, Mode, -1 );
 }
 // 
 // 
@@ -1531,36 +1229,39 @@ gchar *VarOptionsFileOgg[] = {
 // 
 void on_type_file_ogg_activate( GtkMenuItem *menuitem, gpointer user_data )
 {
-	gint	Choice = GPOINTER_TO_INT(user_data);
+	gint	Choice  = GPOINTER_TO_INT(user_data);
+	gint	Debit   = Detail_VarOptionsFileOggMp3->Ogg_Debit;
+	gint	Managed = Detail_VarOptionsFileOggMp3->Ogg_Managed;
+	gint	Downmix = Detail_VarOptionsFileOggMp3->Ogg_Downmix;
 	
 	if( -1 == Choice ) {
 		// g_print( "REMOVE\n");
-		Detail_VarOptionsFileOggMp3->Ogg_Debit   = -1;	// SET DEBIT
-		Detail_VarOptionsFileOggMp3->Ogg_Managed = -1;	// SET MANAGED
-		Detail_VarOptionsFileOggMp3->Ogg_Downmix = -1;	// SET DOWNMIX
-		FileMp3Ogg_update_newbitrate( FILE_IS_OGG );
+		Debit   = Detail_VarOptionsFileOggMp3->Ogg_Debit   = -1;	// SET DEBIT
+		Managed = Detail_VarOptionsFileOggMp3->Ogg_Managed = -1;	// SET MANAGED
+		Downmix = Detail_VarOptionsFileOggMp3->Ogg_Downmix = -1;	// SET DOWNMIX
+		FileMp3Ogg_update_newbitrate( FILE_IS_OGG, Debit, Managed, Downmix );
 		return;
 	}
 	
 	// OGG: DEBIT MANAGED DOWNMIX
 	if( Choice <= 22 )
-		Detail_VarOptionsFileOggMp3->Ogg_Debit = Choice;	// SET DEBIT
+		Debit   = Detail_VarOptionsFileOggMp3->Ogg_Debit = Choice;	// SET DEBIT
 	else if( Choice <= 24)
-		Detail_VarOptionsFileOggMp3->Ogg_Managed = Choice;	// SET MANAGED
+		Managed = Detail_VarOptionsFileOggMp3->Ogg_Managed = Choice;	// SET MANAGED
 	else
-		Detail_VarOptionsFileOggMp3->Ogg_Downmix = Choice;	// SET DOWNMIX
+		Downmix = Detail_VarOptionsFileOggMp3->Ogg_Downmix = Choice;	// SET DOWNMIX
 	
 	// SELECTIONS DES DEUX OPTIONS OBLIGATOIRE
-	if( -1 == Detail_VarOptionsFileOggMp3->Ogg_Debit )	Detail_VarOptionsFileOggMp3->Ogg_Debit   = 0;
-	if( -1 == Detail_VarOptionsFileOggMp3->Ogg_Managed )	Detail_VarOptionsFileOggMp3->Ogg_Managed = 23;
-	if( -1 == Detail_VarOptionsFileOggMp3->Ogg_Downmix )	Detail_VarOptionsFileOggMp3->Ogg_Downmix = 25;
+	if( -1 == Detail_VarOptionsFileOggMp3->Ogg_Debit )	Debit   = Detail_VarOptionsFileOggMp3->Ogg_Debit   = 0;
+	if( -1 == Detail_VarOptionsFileOggMp3->Ogg_Managed )	Managed = Detail_VarOptionsFileOggMp3->Ogg_Managed = 23;
+	if( -1 == Detail_VarOptionsFileOggMp3->Ogg_Downmix )	Downmix = Detail_VarOptionsFileOggMp3->Ogg_Downmix = 25;
 	
-	if( Detail_VarOptionsFileOggMp3->Ogg_Debit >= 11 )	Detail_VarOptionsFileOggMp3->Ogg_Managed = -1;
-	if( Detail_VarOptionsFileOggMp3->Ogg_Debit >= 9 )	Detail_VarOptionsFileOggMp3->Ogg_Downmix = -1;
+	if( Detail_VarOptionsFileOggMp3->Ogg_Debit >= 11 )	Managed = Detail_VarOptionsFileOggMp3->Ogg_Managed = -1;
+	if( Detail_VarOptionsFileOggMp3->Ogg_Debit >= 9 )	Downmix = Detail_VarOptionsFileOggMp3->Ogg_Downmix = -1;
 	
 	Detail_VarOptionsFileOggMp3->BoolChanged = ( -1 != Detail_VarOptionsFileOggMp3->Ogg_Debit || -1 != Detail_VarOptionsFileOggMp3->Ogg_Managed || -1 != Detail_VarOptionsFileOggMp3->Ogg_Downmix );
 	
-	FileMp3Ogg_update_newbitrate( FILE_IS_OGG );
+	FileMp3Ogg_update_newbitrate( FILE_IS_OGG, Debit, Managed, Downmix );
 }
 // 
 // 
