@@ -28,11 +28,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define gettext_noop(x) (x)
-#endif
-
 #include <gtk/gtk.h>
 #include <string.h>
 
