@@ -29,11 +29,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <glib.h>
 #include <glib/gstdio.h>
@@ -118,6 +113,7 @@ gchar *SplitCue_read_cue_file (gchar *p_pathname)
 	
 	if (NULL == (fp = fopen (p_pathname, "r"))) {
 		wininfo_create (
+			WindMain,
 			_("Erreur de lecture !"),
 			  "");
 		return (NULL);
@@ -178,6 +174,7 @@ gchar *SplitCue_read_cue_file (gchar *p_pathname)
 	// LES TESTS
 	if (NULL == PathNameSong) {
 		wininfo_create (
+			WindMain,
 			_("Erreur"),
 			_("Aucun fichier de musique associe au cue-file !"),
 			  "");
@@ -187,6 +184,7 @@ gchar *SplitCue_read_cue_file (gchar *p_pathname)
 		if( TRUE == OptionsCommandLine.BoolVerboseMode )
 			g_print ("====\n%s\n----\n%s\t%s\n\t\tFILE NOT IN: .wav\n====\n", p_pathname, buf, PathNameSong);
 		wininfo_create (
+			WindMain,
 			_("Erreur"),
 			_("Pas de fichier WAV dans le cue-file !"),
 			  "");
@@ -196,6 +194,7 @@ gchar *SplitCue_read_cue_file (gchar *p_pathname)
 	if (FALSE == libutils_test_file_exist (PathNameSong)) {
 		PRINT("AUCUN FICHIER DE MUSIQUE ASSOCIE DANS LE DOSSIER");
 		wininfo_create (
+			WindMain,
 			_("Erreur"),
 			_("Aucun fichier de musique associe dans le dossier"),
 			  "\n",
@@ -285,6 +284,7 @@ gchar *SplitCue_read_cue_file (gchar *p_pathname)
 			PathNameSong = NULL;
 			
 			wininfo_create (
+				WindMain,
 				_("Erreur de donnees dans le fichier CUE"),
 				_("La solution est d'importer le fichier de"),
 				  "\n",
@@ -313,11 +313,12 @@ void on_button_gen_cue_split_clicked (GtkButton *button, gpointer user_data)
 {
 	gint		IndicePoints;
 	gdouble		Percent;
-	gint		H, M, S, C;
+	// gint		H;
+	gint		M, S, C;
+	gint		hundr;
 	gint		sec;
 	gdouble		dsec;
 	gdouble		TimeSongSec;
-	gint		hundr;
 	gchar		*Ptr = NULL;
 	gchar		*PathNameFileCue = NULL;
 	gchar		*NameFileWav = NULL;
@@ -335,7 +336,7 @@ void on_button_gen_cue_split_clicked (GtkButton *button, gpointer user_data)
 		sec = (gint) (((gdouble)TimeSongSec * (gdouble)Percent) / 100.0);
 		dsec  = ((gdouble)TimeSongSec *(gdouble)Percent) / 100.0;
 		hundr = ((gdouble)dsec - (gdouble)sec) * 100.0;
-		H = (sec / 60) / 60;
+		// H = (sec / 60) / 60;
 		M = (sec / 60) % 60;
 		S = sec % 60;
 		C = hundr;
@@ -349,7 +350,7 @@ void on_button_gen_cue_split_clicked (GtkButton *button, gpointer user_data)
 		sec = (gint) (((gdouble)TimeSongSec * (gdouble)Percent) / 100.0);
 		dsec  = ((gdouble)TimeSongSec *(gdouble)Percent) / 100.0;
 		hundr = ((gdouble)dsec - (gdouble)sec) * 100.0;
-		H = (sec / 60) / 60;
+		// H = (sec / 60) / 60;
 		M = (sec / 60) % 60;
 		S = sec % 60;
 		C = hundr;
@@ -442,7 +443,7 @@ void on_button_gen_cue_split_clicked (GtkButton *button, gpointer user_data)
 			sec = (gint) (((gdouble)TimeSongSec * (gdouble)Percent) / 100.0);
 			dsec  = ((gdouble)TimeSongSec *(gdouble)Percent) / 100.0;
 			hundr = ((gdouble)dsec - (gdouble)sec) * 100.0;
-			H = (sec / 60) / 60;
+			// H = (sec / 60) / 60;
 			M = (sec / 60) % 60;
 			S = sec % 60;
 			C = hundr;
@@ -456,7 +457,7 @@ void on_button_gen_cue_split_clicked (GtkButton *button, gpointer user_data)
 		sec = (gint) (((gdouble)TimeSongSec * (gdouble)Percent) / 100.0);
 		dsec  = ((gdouble)TimeSongSec *(gdouble)Percent) / 100.0;
 		hundr = ((gdouble)dsec - (gdouble)sec) * 100.0;
-		H = (sec / 60) / 60;
+		// H = (sec / 60) / 60;
 		M = (sec / 60) % 60;
 		S = sec % 60;
 		C = hundr;
