@@ -29,11 +29,6 @@
 	#include "../config.h"
 #endif
 
-#ifdef ENABLE_NLS
-	#include <libintl.h>
-	#define _(String) gettext (String)
-#endif
-
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <string.h>
@@ -52,9 +47,6 @@
 
 
 
-
-
-
 #define MAX_DATAS_STRUCT_RADIOBUTTONS 6
 
 typedef struct {
