@@ -29,7 +29,7 @@
 #define win_info_h 1
 
 
-void wininfo_create (gchar *title, ...);
+void wininfo_create( GtkWidget *p_WindMain, gchar *title, ... );
 
 
 #endif
