@@ -39,7 +39,6 @@
 
 #include "global.h"
 #include "mplayer.h"
-#include "popup_systray.h"
 #include "win_reader.h"
 
 
@@ -125,7 +124,6 @@ gboolean on_WindReader_delete_event (GtkWidget *widget, GdkEvent *event, gpointe
 	mplayer_fifo_quit ();
 	VarWindReader.IsShow = FALSE;
 	gtk_widget_hide (VarWindReader.AdrWin);
-	PopupSystray_set_BoolMainAction (FALSE);
 	return TRUE;
 }
 // DESTROY EVENT
@@ -135,7 +133,6 @@ gboolean on_WindReader_destroy_event (GtkWidget *widget, GdkEvent *event, gpoint
 	mplayer_fifo_quit ();
 	VarWindReader.IsShow = FALSE;
 	gtk_widget_hide (VarWindReader.AdrWin);
-	PopupSystray_set_BoolMainAction (FALSE);
 	return TRUE;
 }
 // PAUSE
@@ -168,7 +165,6 @@ void on_button_quitter_WindReader_clicked (GtkButton *button, gpointer user_data
 	mplayer_fifo_quit ();
 	VarWindReader.IsShow = FALSE;
 	gtk_widget_hide (VarWindReader.AdrWin);
-	PopupSystray_set_BoolMainAction (FALSE);
 }
 // WIN-READER OPEN
 // 
@@ -198,7 +194,6 @@ void WinReader_open (gchar *title)
 	else {
 		gtk_widget_show (GTK_WIDGET (GLADE_GET_OBJECT("hbox_WindReader")));
 	}
-	PopupSystray_set_BoolMainAction (TRUE);
 }
 // WIN-READER SET-TITLE
 // 
@@ -232,7 +227,6 @@ void WinReader_close (void)
 		WinReader_set_lecture ();
 		VarWindReader.IsShow = FALSE;
 		gtk_widget_hide (VarWindReader.AdrWin);
-		PopupSystray_set_BoolMainAction (FALSE);
 	}
 }
 // WIN-READER IS OK
